# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class PkiTidyCancelResponse(BaseModel):
    """
    PkiTidyCancelResponse
    """ # noqa: E501
    acme_account_deleted_count: Optional[StrictInt] = Field(default=None, description="The number of revoked acme accounts removed")
    acme_account_revoked_count: Optional[StrictInt] = Field(default=None, description="The number of unused acme accounts revoked")
    acme_account_safety_buffer: Optional[StrictInt] = Field(default=None, description="Safety buffer after creation after which accounts lacking orders are revoked")
    acme_orders_deleted_count: Optional[StrictInt] = Field(default=None, description="The number of expired, unused acme orders removed")
    cert_store_deleted_count: Optional[StrictInt] = Field(default=None, description="The number of certificate storage entries deleted")
    cross_revoked_cert_deleted_count: Optional[StrictInt] = None
    current_cert_store_count: Optional[StrictInt] = Field(default=None, description="The number of revoked certificate entries deleted")
    current_revoked_cert_count: Optional[StrictInt] = Field(default=None, description="The number of revoked certificate entries deleted")
    error: Optional[StrictStr] = Field(default=None, description="The error message")
    internal_backend_uuid: Optional[StrictStr] = None
    issuer_safety_buffer: Optional[StrictInt] = Field(default=None, description="Issuer safety buffer")
    last_auto_tidy_finished: Optional[StrictStr] = Field(default=None, description="Time the last auto-tidy operation finished")
    message: Optional[StrictStr] = Field(default=None, description="Message of the operation")
    missing_issuer_cert_count: Optional[StrictInt] = None
    pause_duration: Optional[StrictStr] = Field(default=None, description="Duration to pause between tidying certificates")
    revocation_queue_deleted_count: Optional[StrictInt] = None
    revocation_queue_safety_buffer: Optional[StrictInt] = Field(default=None, description="Revocation queue safety buffer")
    revoked_cert_deleted_count: Optional[StrictInt] = Field(default=None, description="The number of revoked certificate entries deleted")
    safety_buffer: Optional[StrictInt] = Field(default=None, description="Safety buffer time duration")
    state: Optional[StrictStr] = Field(default=None, description="One of Inactive, Running, Finished, or Error")
    tidy_acme: Optional[StrictBool] = Field(default=None, description="Tidy Unused Acme Accounts, and Orders")
    tidy_cert_store: Optional[StrictBool] = Field(default=None, description="Tidy certificate store")
    tidy_cross_cluster_revoked_certs: Optional[StrictBool] = Field(default=None, description="Tidy the cross-cluster revoked certificate store")
    tidy_expired_issuers: Optional[StrictBool] = Field(default=None, description="Tidy expired issuers")
    tidy_move_legacy_ca_bundle: Optional[StrictBool] = None
    tidy_revocation_queue: Optional[StrictBool] = None
    tidy_revoked_cert_issuer_associations: Optional[StrictBool] = Field(default=None, description="Tidy revoked certificate issuer associations")
    tidy_revoked_certs: Optional[StrictBool] = Field(default=None, description="Tidy revoked certificates")
    time_finished: Optional[StrictStr] = Field(default=None, description="Time the operation finished")
    time_started: Optional[StrictStr] = Field(default=None, description="Time the operation started")
    total_acme_account_count: Optional[StrictInt] = Field(default=None, description="Total number of acme accounts iterated over")
    __properties: ClassVar[List[str]] = ["acme_account_deleted_count", "acme_account_revoked_count", "acme_account_safety_buffer", "acme_orders_deleted_count", "cert_store_deleted_count", "cross_revoked_cert_deleted_count", "current_cert_store_count", "current_revoked_cert_count", "error", "internal_backend_uuid", "issuer_safety_buffer", "last_auto_tidy_finished", "message", "missing_issuer_cert_count", "pause_duration", "revocation_queue_deleted_count", "revocation_queue_safety_buffer", "revoked_cert_deleted_count", "safety_buffer", "state", "tidy_acme", "tidy_cert_store", "tidy_cross_cluster_revoked_certs", "tidy_expired_issuers", "tidy_move_legacy_ca_bundle", "tidy_revocation_queue", "tidy_revoked_cert_issuer_associations", "tidy_revoked_certs", "time_finished", "time_started", "total_acme_account_count"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PkiTidyCancelResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PkiTidyCancelResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "acme_account_deleted_count": obj.get("acme_account_deleted_count"),
            "acme_account_revoked_count": obj.get("acme_account_revoked_count"),
            "acme_account_safety_buffer": obj.get("acme_account_safety_buffer"),
            "acme_orders_deleted_count": obj.get("acme_orders_deleted_count"),
            "cert_store_deleted_count": obj.get("cert_store_deleted_count"),
            "cross_revoked_cert_deleted_count": obj.get("cross_revoked_cert_deleted_count"),
            "current_cert_store_count": obj.get("current_cert_store_count"),
            "current_revoked_cert_count": obj.get("current_revoked_cert_count"),
            "error": obj.get("error"),
            "internal_backend_uuid": obj.get("internal_backend_uuid"),
            "issuer_safety_buffer": obj.get("issuer_safety_buffer"),
            "last_auto_tidy_finished": obj.get("last_auto_tidy_finished"),
            "message": obj.get("message"),
            "missing_issuer_cert_count": obj.get("missing_issuer_cert_count"),
            "pause_duration": obj.get("pause_duration"),
            "revocation_queue_deleted_count": obj.get("revocation_queue_deleted_count"),
            "revocation_queue_safety_buffer": obj.get("revocation_queue_safety_buffer"),
            "revoked_cert_deleted_count": obj.get("revoked_cert_deleted_count"),
            "safety_buffer": obj.get("safety_buffer"),
            "state": obj.get("state"),
            "tidy_acme": obj.get("tidy_acme"),
            "tidy_cert_store": obj.get("tidy_cert_store"),
            "tidy_cross_cluster_revoked_certs": obj.get("tidy_cross_cluster_revoked_certs"),
            "tidy_expired_issuers": obj.get("tidy_expired_issuers"),
            "tidy_move_legacy_ca_bundle": obj.get("tidy_move_legacy_ca_bundle"),
            "tidy_revocation_queue": obj.get("tidy_revocation_queue"),
            "tidy_revoked_cert_issuer_associations": obj.get("tidy_revoked_cert_issuer_associations"),
            "tidy_revoked_certs": obj.get("tidy_revoked_certs"),
            "time_finished": obj.get("time_finished"),
            "time_started": obj.get("time_started"),
            "total_acme_account_count": obj.get("total_acme_account_count")
        })
        return _obj





# coding: utf-8

# flake8: noqa

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.15.0"

# import apis into sdk package
from ahvac.api.auth_api import AuthApi
from ahvac.api.identity_api import IdentityApi
from ahvac.api.secrets_api import SecretsApi
from ahvac.api.system_api import SystemApi

# import ApiClient
from ahvac.api_response import ApiResponse
from ahvac.api_client import ApiClient
from ahvac.configuration import Configuration
from ahvac.exceptions import OpenApiException
from ahvac.exceptions import ApiTypeError
from ahvac.exceptions import ApiValueError
from ahvac.exceptions import ApiKeyError
from ahvac.exceptions import ApiAttributeError
from ahvac.exceptions import ApiException

# import models into sdk package
from ahvac.models.ali_cloud_configure_request import AliCloudConfigureRequest
from ahvac.models.ali_cloud_login_request import AliCloudLoginRequest
from ahvac.models.ali_cloud_write_auth_role_request import AliCloudWriteAuthRoleRequest
from ahvac.models.ali_cloud_write_role_request import AliCloudWriteRoleRequest
from ahvac.models.alias_create_request import AliasCreateRequest
from ahvac.models.alias_update_by_id_request import AliasUpdateByIdRequest
from ahvac.models.app_role_destroy_secret_id_by_accessor_request import AppRoleDestroySecretIdByAccessorRequest
from ahvac.models.app_role_destroy_secret_id_request import AppRoleDestroySecretIdRequest
from ahvac.models.app_role_login_request import AppRoleLoginRequest
from ahvac.models.app_role_login_response import AppRoleLoginResponse
from ahvac.models.app_role_look_up_secret_id_by_accessor_request import AppRoleLookUpSecretIdByAccessorRequest
from ahvac.models.app_role_look_up_secret_id_by_accessor_response import AppRoleLookUpSecretIdByAccessorResponse
from ahvac.models.app_role_look_up_secret_id_request import AppRoleLookUpSecretIdRequest
from ahvac.models.app_role_look_up_secret_id_response import AppRoleLookUpSecretIdResponse
from ahvac.models.app_role_read_bind_secret_id_response import AppRoleReadBindSecretIdResponse
from ahvac.models.app_role_read_bound_cidr_list_response import AppRoleReadBoundCidrListResponse
from ahvac.models.app_role_read_local_secret_ids_response import AppRoleReadLocalSecretIdsResponse
from ahvac.models.app_role_read_period_response import AppRoleReadPeriodResponse
from ahvac.models.app_role_read_policies_response import AppRoleReadPoliciesResponse
from ahvac.models.app_role_read_role_id_response import AppRoleReadRoleIdResponse
from ahvac.models.app_role_read_role_response import AppRoleReadRoleResponse
from ahvac.models.app_role_read_secret_id_bound_cidrs_response import AppRoleReadSecretIdBoundCidrsResponse
from ahvac.models.app_role_read_secret_id_num_uses_response import AppRoleReadSecretIdNumUsesResponse
from ahvac.models.app_role_read_secret_id_ttl_response import AppRoleReadSecretIdTtlResponse
from ahvac.models.app_role_read_token_bound_cidrs_response import AppRoleReadTokenBoundCidrsResponse
from ahvac.models.app_role_read_token_max_ttl_response import AppRoleReadTokenMaxTtlResponse
from ahvac.models.app_role_read_token_num_uses_response import AppRoleReadTokenNumUsesResponse
from ahvac.models.app_role_read_token_ttl_response import AppRoleReadTokenTtlResponse
from ahvac.models.app_role_write_bind_secret_id_request import AppRoleWriteBindSecretIdRequest
from ahvac.models.app_role_write_bound_cidr_list_request import AppRoleWriteBoundCidrListRequest
from ahvac.models.app_role_write_custom_secret_id_request import AppRoleWriteCustomSecretIdRequest
from ahvac.models.app_role_write_custom_secret_id_response import AppRoleWriteCustomSecretIdResponse
from ahvac.models.app_role_write_period_request import AppRoleWritePeriodRequest
from ahvac.models.app_role_write_policies_request import AppRoleWritePoliciesRequest
from ahvac.models.app_role_write_role_id_request import AppRoleWriteRoleIdRequest
from ahvac.models.app_role_write_role_request import AppRoleWriteRoleRequest
from ahvac.models.app_role_write_secret_id_bound_cidrs_request import AppRoleWriteSecretIdBoundCidrsRequest
from ahvac.models.app_role_write_secret_id_num_uses_request import AppRoleWriteSecretIdNumUsesRequest
from ahvac.models.app_role_write_secret_id_request import AppRoleWriteSecretIdRequest
from ahvac.models.app_role_write_secret_id_response import AppRoleWriteSecretIdResponse
from ahvac.models.app_role_write_secret_id_ttl_request import AppRoleWriteSecretIdTtlRequest
from ahvac.models.app_role_write_token_bound_cidrs_request import AppRoleWriteTokenBoundCidrsRequest
from ahvac.models.app_role_write_token_max_ttl_request import AppRoleWriteTokenMaxTtlRequest
from ahvac.models.app_role_write_token_num_uses_request import AppRoleWriteTokenNumUsesRequest
from ahvac.models.app_role_write_token_ttl_request import AppRoleWriteTokenTtlRequest
from ahvac.models.auditing_calculate_hash_request import AuditingCalculateHashRequest
from ahvac.models.auditing_calculate_hash_response import AuditingCalculateHashResponse
from ahvac.models.auditing_enable_device_request import AuditingEnableDeviceRequest
from ahvac.models.auditing_enable_request_header_request import AuditingEnableRequestHeaderRequest
from ahvac.models.auditing_list_request_headers_response import AuditingListRequestHeadersResponse
from ahvac.models.auth_enable_method_request import AuthEnableMethodRequest
from ahvac.models.auth_read_configuration_response import AuthReadConfigurationResponse
from ahvac.models.auth_read_tuning_information_response import AuthReadTuningInformationResponse
from ahvac.models.auth_tune_configuration_parameters_request import AuthTuneConfigurationParametersRequest
from ahvac.models.aws_configure_certificate_request import AwsConfigureCertificateRequest
from ahvac.models.aws_configure_client_request import AwsConfigureClientRequest
from ahvac.models.aws_configure_identity_access_list_tidy_operation_request import AwsConfigureIdentityAccessListTidyOperationRequest
from ahvac.models.aws_configure_identity_integration_request import AwsConfigureIdentityIntegrationRequest
from ahvac.models.aws_configure_identity_whitelist_tidy_operation_request import AwsConfigureIdentityWhitelistTidyOperationRequest
from ahvac.models.aws_configure_lease_request import AwsConfigureLeaseRequest
from ahvac.models.aws_configure_role_tag_blacklist_tidy_operation_request import AwsConfigureRoleTagBlacklistTidyOperationRequest
from ahvac.models.aws_configure_role_tag_deny_list_tidy_operation_request import AwsConfigureRoleTagDenyListTidyOperationRequest
from ahvac.models.aws_configure_root_iam_credentials_request import AwsConfigureRootIamCredentialsRequest
from ahvac.models.aws_generate_credentials_with_parameters_request import AwsGenerateCredentialsWithParametersRequest
from ahvac.models.aws_generate_sts_credentials_with_parameters_request import AwsGenerateStsCredentialsWithParametersRequest
from ahvac.models.aws_login_request import AwsLoginRequest
from ahvac.models.aws_read_static_creds_name_response import AwsReadStaticCredsNameResponse
from ahvac.models.aws_read_static_roles_name_response import AwsReadStaticRolesNameResponse
from ahvac.models.aws_tidy_identity_access_list_request import AwsTidyIdentityAccessListRequest
from ahvac.models.aws_tidy_identity_whitelist_request import AwsTidyIdentityWhitelistRequest
from ahvac.models.aws_tidy_role_tag_blacklist_request import AwsTidyRoleTagBlacklistRequest
from ahvac.models.aws_tidy_role_tag_deny_list_request import AwsTidyRoleTagDenyListRequest
from ahvac.models.aws_write_auth_role_request import AwsWriteAuthRoleRequest
from ahvac.models.aws_write_role_request import AwsWriteRoleRequest
from ahvac.models.aws_write_role_tag_request import AwsWriteRoleTagRequest
from ahvac.models.aws_write_static_roles_name_request import AwsWriteStaticRolesNameRequest
from ahvac.models.aws_write_static_roles_name_response import AwsWriteStaticRolesNameResponse
from ahvac.models.aws_write_sts_role_request import AwsWriteStsRoleRequest
from ahvac.models.azure_configure_auth_request import AzureConfigureAuthRequest
from ahvac.models.azure_configure_request import AzureConfigureRequest
from ahvac.models.azure_login_request import AzureLoginRequest
from ahvac.models.azure_write_auth_role_request import AzureWriteAuthRoleRequest
from ahvac.models.azure_write_role_request import AzureWriteRoleRequest
from ahvac.models.centrify_configure_request import CentrifyConfigureRequest
from ahvac.models.centrify_login_request import CentrifyLoginRequest
from ahvac.models.cert_configure_request import CertConfigureRequest
from ahvac.models.cert_login_request import CertLoginRequest
from ahvac.models.cert_write_certificate_request import CertWriteCertificateRequest
from ahvac.models.cert_write_crl_request import CertWriteCrlRequest
from ahvac.models.cloud_foundry_configure_request import CloudFoundryConfigureRequest
from ahvac.models.cloud_foundry_login_request import CloudFoundryLoginRequest
from ahvac.models.cloud_foundry_write_role_request import CloudFoundryWriteRoleRequest
from ahvac.models.collect_host_information_response import CollectHostInformationResponse
from ahvac.models.consul_configure_access_request import ConsulConfigureAccessRequest
from ahvac.models.consul_write_role_request import ConsulWriteRoleRequest
from ahvac.models.cors_configure_request import CorsConfigureRequest
from ahvac.models.cors_read_configuration_response import CorsReadConfigurationResponse
from ahvac.models.database_configure_connection_request import DatabaseConfigureConnectionRequest
from ahvac.models.database_write_role_request import DatabaseWriteRoleRequest
from ahvac.models.database_write_static_role_request import DatabaseWriteStaticRoleRequest
from ahvac.models.decode_request import DecodeRequest
from ahvac.models.encryption_key_configure_rotation_request import EncryptionKeyConfigureRotationRequest
from ahvac.models.encryption_key_read_rotation_configuration_response import EncryptionKeyReadRotationConfigurationResponse
from ahvac.models.entity_batch_delete_request import EntityBatchDeleteRequest
from ahvac.models.entity_create_alias_request import EntityCreateAliasRequest
from ahvac.models.entity_create_request import EntityCreateRequest
from ahvac.models.entity_look_up_request import EntityLookUpRequest
from ahvac.models.entity_merge_request import EntityMergeRequest
from ahvac.models.entity_update_alias_by_id_request import EntityUpdateAliasByIdRequest
from ahvac.models.entity_update_by_id_request import EntityUpdateByIdRequest
from ahvac.models.entity_update_by_name_request import EntityUpdateByNameRequest
from ahvac.models.generate_hash_request import GenerateHashRequest
from ahvac.models.generate_hash_response import GenerateHashResponse
from ahvac.models.generate_hash_with_algorithm_request import GenerateHashWithAlgorithmRequest
from ahvac.models.generate_hash_with_algorithm_response import GenerateHashWithAlgorithmResponse
from ahvac.models.generate_random_request import GenerateRandomRequest
from ahvac.models.generate_random_response import GenerateRandomResponse
from ahvac.models.generate_random_with_bytes_request import GenerateRandomWithBytesRequest
from ahvac.models.generate_random_with_bytes_response import GenerateRandomWithBytesResponse
from ahvac.models.generate_random_with_source_and_bytes_request import GenerateRandomWithSourceAndBytesRequest
from ahvac.models.generate_random_with_source_and_bytes_response import GenerateRandomWithSourceAndBytesResponse
from ahvac.models.generate_random_with_source_request import GenerateRandomWithSourceRequest
from ahvac.models.generate_random_with_source_response import GenerateRandomWithSourceResponse
from ahvac.models.github_configure_request import GithubConfigureRequest
from ahvac.models.github_login_request import GithubLoginRequest
from ahvac.models.github_write_team_mapping_request import GithubWriteTeamMappingRequest
from ahvac.models.github_write_user_mapping_request import GithubWriteUserMappingRequest
from ahvac.models.google_cloud_configure_auth_request import GoogleCloudConfigureAuthRequest
from ahvac.models.google_cloud_configure_request import GoogleCloudConfigureRequest
from ahvac.models.google_cloud_edit_labels_for_role_request import GoogleCloudEditLabelsForRoleRequest
from ahvac.models.google_cloud_edit_service_accounts_for_role_request import GoogleCloudEditServiceAccountsForRoleRequest
from ahvac.models.google_cloud_generate_roleset_key3_request import GoogleCloudGenerateRolesetKey3Request
from ahvac.models.google_cloud_generate_roleset_key_request import GoogleCloudGenerateRolesetKeyRequest
from ahvac.models.google_cloud_generate_static_account_key_request import GoogleCloudGenerateStaticAccountKeyRequest
from ahvac.models.google_cloud_kms_configure_key_request import GoogleCloudKmsConfigureKeyRequest
from ahvac.models.google_cloud_kms_configure_request import GoogleCloudKmsConfigureRequest
from ahvac.models.google_cloud_kms_decrypt_request import GoogleCloudKmsDecryptRequest
from ahvac.models.google_cloud_kms_encrypt_request import GoogleCloudKmsEncryptRequest
from ahvac.models.google_cloud_kms_reencrypt_request import GoogleCloudKmsReencryptRequest
from ahvac.models.google_cloud_kms_register_key_request import GoogleCloudKmsRegisterKeyRequest
from ahvac.models.google_cloud_kms_sign_request import GoogleCloudKmsSignRequest
from ahvac.models.google_cloud_kms_verify_request import GoogleCloudKmsVerifyRequest
from ahvac.models.google_cloud_kms_write_key_request import GoogleCloudKmsWriteKeyRequest
from ahvac.models.google_cloud_login_request import GoogleCloudLoginRequest
from ahvac.models.google_cloud_write_impersonated_account_request import GoogleCloudWriteImpersonatedAccountRequest
from ahvac.models.google_cloud_write_role_request import GoogleCloudWriteRoleRequest
from ahvac.models.google_cloud_write_roleset_request import GoogleCloudWriteRolesetRequest
from ahvac.models.google_cloud_write_static_account_request import GoogleCloudWriteStaticAccountRequest
from ahvac.models.group_create_alias_request import GroupCreateAliasRequest
from ahvac.models.group_create_request import GroupCreateRequest
from ahvac.models.group_look_up_request import GroupLookUpRequest
from ahvac.models.group_update_alias_by_id_request import GroupUpdateAliasByIdRequest
from ahvac.models.group_update_by_id_request import GroupUpdateByIdRequest
from ahvac.models.group_update_by_name_request import GroupUpdateByNameRequest
from ahvac.models.ha_status_response import HaStatusResponse
from ahvac.models.initialize_request import InitializeRequest
from ahvac.models.internal_client_activity_configure_request import InternalClientActivityConfigureRequest
from ahvac.models.internal_count_entities_response import InternalCountEntitiesResponse
from ahvac.models.internal_count_tokens_response import InternalCountTokensResponse
from ahvac.models.internal_generate_open_api_document_with_parameters_request import InternalGenerateOpenApiDocumentWithParametersRequest
from ahvac.models.internal_ui_list_enabled_feature_flags_response import InternalUiListEnabledFeatureFlagsResponse
from ahvac.models.internal_ui_list_enabled_visible_mounts_response import InternalUiListEnabledVisibleMountsResponse
from ahvac.models.internal_ui_list_namespaces_response import InternalUiListNamespacesResponse
from ahvac.models.internal_ui_read_mount_information_response import InternalUiReadMountInformationResponse
from ahvac.models.internal_ui_read_resultant_acl_response import InternalUiReadResultantAclResponse
from ahvac.models.jwt_configure_request import JwtConfigureRequest
from ahvac.models.jwt_login_request import JwtLoginRequest
from ahvac.models.jwt_oidc_callback_form_post_request import JwtOidcCallbackFormPostRequest
from ahvac.models.jwt_oidc_request_authorization_url_request import JwtOidcRequestAuthorizationUrlRequest
from ahvac.models.jwt_write_role_request import JwtWriteRoleRequest
from ahvac.models.kerberos_configure_ldap_request import KerberosConfigureLdapRequest
from ahvac.models.kerberos_configure_request import KerberosConfigureRequest
from ahvac.models.kerberos_login_request import KerberosLoginRequest
from ahvac.models.kerberos_write_group_request import KerberosWriteGroupRequest
from ahvac.models.kubernetes_configure_auth_request import KubernetesConfigureAuthRequest
from ahvac.models.kubernetes_configure_request import KubernetesConfigureRequest
from ahvac.models.kubernetes_generate_credentials_request import KubernetesGenerateCredentialsRequest
from ahvac.models.kubernetes_login_request import KubernetesLoginRequest
from ahvac.models.kubernetes_write_auth_role_request import KubernetesWriteAuthRoleRequest
from ahvac.models.kubernetes_write_role_request import KubernetesWriteRoleRequest
from ahvac.models.kv_v2_configure_request import KvV2ConfigureRequest
from ahvac.models.kv_v2_delete_versions_request import KvV2DeleteVersionsRequest
from ahvac.models.kv_v2_destroy_versions_request import KvV2DestroyVersionsRequest
from ahvac.models.kv_v2_patch_response import KvV2PatchResponse
from ahvac.models.kv_v2_read_configuration_response import KvV2ReadConfigurationResponse
from ahvac.models.kv_v2_read_metadata_response import KvV2ReadMetadataResponse
from ahvac.models.kv_v2_read_response import KvV2ReadResponse
from ahvac.models.kv_v2_read_subkeys_response import KvV2ReadSubkeysResponse
from ahvac.models.kv_v2_undelete_versions_request import KvV2UndeleteVersionsRequest
from ahvac.models.kv_v2_write_metadata_request import KvV2WriteMetadataRequest
from ahvac.models.kv_v2_write_request import KvV2WriteRequest
from ahvac.models.kv_v2_write_response import KvV2WriteResponse
from ahvac.models.ldap_configure_auth_request import LdapConfigureAuthRequest
from ahvac.models.ldap_configure_request import LdapConfigureRequest
from ahvac.models.ldap_library_check_in_request import LdapLibraryCheckInRequest
from ahvac.models.ldap_library_check_out_request import LdapLibraryCheckOutRequest
from ahvac.models.ldap_library_configure_request import LdapLibraryConfigureRequest
from ahvac.models.ldap_library_force_check_in_request import LdapLibraryForceCheckInRequest
from ahvac.models.ldap_login_request import LdapLoginRequest
from ahvac.models.ldap_write_dynamic_role_request import LdapWriteDynamicRoleRequest
from ahvac.models.ldap_write_group_request import LdapWriteGroupRequest
from ahvac.models.ldap_write_static_role_request import LdapWriteStaticRoleRequest
from ahvac.models.ldap_write_user_request import LdapWriteUserRequest
from ahvac.models.leader_status_response import LeaderStatusResponse
from ahvac.models.leases_count_response import LeasesCountResponse
from ahvac.models.leases_list_response import LeasesListResponse
from ahvac.models.leases_look_up_response import LeasesLookUpResponse
from ahvac.models.leases_read_lease_request import LeasesReadLeaseRequest
from ahvac.models.leases_read_lease_response import LeasesReadLeaseResponse
from ahvac.models.leases_renew_lease2_request import LeasesRenewLease2Request
from ahvac.models.leases_renew_lease_request import LeasesRenewLeaseRequest
from ahvac.models.leases_renew_lease_with_id2_request import LeasesRenewLeaseWithId2Request
from ahvac.models.leases_renew_lease_with_id_request import LeasesRenewLeaseWithIdRequest
from ahvac.models.leases_revoke_lease2_request import LeasesRevokeLease2Request
from ahvac.models.leases_revoke_lease_request import LeasesRevokeLeaseRequest
from ahvac.models.leases_revoke_lease_with_id2_request import LeasesRevokeLeaseWithId2Request
from ahvac.models.leases_revoke_lease_with_id_request import LeasesRevokeLeaseWithIdRequest
from ahvac.models.leases_revoke_lease_with_prefix2_request import LeasesRevokeLeaseWithPrefix2Request
from ahvac.models.leases_revoke_lease_with_prefix_request import LeasesRevokeLeaseWithPrefixRequest
from ahvac.models.loggers_update_verbosity_level_for_request import LoggersUpdateVerbosityLevelForRequest
from ahvac.models.loggers_update_verbosity_level_request import LoggersUpdateVerbosityLevelRequest
from ahvac.models.mfa_admin_destroy_totp_secret_request import MfaAdminDestroyTotpSecretRequest
from ahvac.models.mfa_admin_generate_totp_secret_request import MfaAdminGenerateTotpSecretRequest
from ahvac.models.mfa_create_duo_method_request import MfaCreateDuoMethodRequest
from ahvac.models.mfa_create_okta_method_request import MfaCreateOktaMethodRequest
from ahvac.models.mfa_create_ping_id_method_request import MfaCreatePingIdMethodRequest
from ahvac.models.mfa_create_totp_method_request import MfaCreateTotpMethodRequest
from ahvac.models.mfa_generate_totp_secret_request import MfaGenerateTotpSecretRequest
from ahvac.models.mfa_update_duo_method_request import MfaUpdateDuoMethodRequest
from ahvac.models.mfa_update_okta_method_request import MfaUpdateOktaMethodRequest
from ahvac.models.mfa_update_ping_id_method_request import MfaUpdatePingIdMethodRequest
from ahvac.models.mfa_update_totp_method_request import MfaUpdateTotpMethodRequest
from ahvac.models.mfa_validate_request import MfaValidateRequest
from ahvac.models.mfa_write_login_enforcement_request import MfaWriteLoginEnforcementRequest
from ahvac.models.mongo_db_atlas_configure_request import MongoDbAtlasConfigureRequest
from ahvac.models.mongo_db_atlas_write_role_request import MongoDbAtlasWriteRoleRequest
from ahvac.models.mounts_enable_secrets_engine_request import MountsEnableSecretsEngineRequest
from ahvac.models.mounts_read_configuration_response import MountsReadConfigurationResponse
from ahvac.models.mounts_read_tuning_information_response import MountsReadTuningInformationResponse
from ahvac.models.mounts_tune_configuration_parameters_request import MountsTuneConfigurationParametersRequest
from ahvac.models.nomad_configure_access_request import NomadConfigureAccessRequest
from ahvac.models.nomad_configure_lease_request import NomadConfigureLeaseRequest
from ahvac.models.nomad_write_role_request import NomadWriteRoleRequest
from ahvac.models.oci_configure_request import OciConfigureRequest
from ahvac.models.oci_login_request import OciLoginRequest
from ahvac.models.oci_write_role_request import OciWriteRoleRequest
from ahvac.models.oidc_configure_request import OidcConfigureRequest
from ahvac.models.oidc_introspect_request import OidcIntrospectRequest
from ahvac.models.oidc_provider_authorize_with_parameters_request import OidcProviderAuthorizeWithParametersRequest
from ahvac.models.oidc_provider_token_request import OidcProviderTokenRequest
from ahvac.models.oidc_rotate_key_request import OidcRotateKeyRequest
from ahvac.models.oidc_write_assignment_request import OidcWriteAssignmentRequest
from ahvac.models.oidc_write_client_request import OidcWriteClientRequest
from ahvac.models.oidc_write_key_request import OidcWriteKeyRequest
from ahvac.models.oidc_write_provider_request import OidcWriteProviderRequest
from ahvac.models.oidc_write_role_request import OidcWriteRoleRequest
from ahvac.models.oidc_write_scope_request import OidcWriteScopeRequest
from ahvac.models.okta_configure_request import OktaConfigureRequest
from ahvac.models.okta_login_request import OktaLoginRequest
from ahvac.models.okta_write_group_request import OktaWriteGroupRequest
from ahvac.models.okta_write_user_request import OktaWriteUserRequest
from ahvac.models.persona_create_request import PersonaCreateRequest
from ahvac.models.persona_update_by_id_request import PersonaUpdateByIdRequest
from ahvac.models.pki_configure_acme_request import PkiConfigureAcmeRequest
from ahvac.models.pki_configure_auto_tidy_request import PkiConfigureAutoTidyRequest
from ahvac.models.pki_configure_auto_tidy_response import PkiConfigureAutoTidyResponse
from ahvac.models.pki_configure_ca_request import PkiConfigureCaRequest
from ahvac.models.pki_configure_ca_response import PkiConfigureCaResponse
from ahvac.models.pki_configure_cluster_request import PkiConfigureClusterRequest
from ahvac.models.pki_configure_cluster_response import PkiConfigureClusterResponse
from ahvac.models.pki_configure_crl_request import PkiConfigureCrlRequest
from ahvac.models.pki_configure_crl_response import PkiConfigureCrlResponse
from ahvac.models.pki_configure_issuers_request import PkiConfigureIssuersRequest
from ahvac.models.pki_configure_issuers_response import PkiConfigureIssuersResponse
from ahvac.models.pki_configure_keys_request import PkiConfigureKeysRequest
from ahvac.models.pki_configure_keys_response import PkiConfigureKeysResponse
from ahvac.models.pki_configure_urls_request import PkiConfigureUrlsRequest
from ahvac.models.pki_configure_urls_response import PkiConfigureUrlsResponse
from ahvac.models.pki_cross_sign_intermediate_request import PkiCrossSignIntermediateRequest
from ahvac.models.pki_cross_sign_intermediate_response import PkiCrossSignIntermediateResponse
from ahvac.models.pki_generate_eab_key_for_issuer_and_role_response import PkiGenerateEabKeyForIssuerAndRoleResponse
from ahvac.models.pki_generate_eab_key_for_issuer_response import PkiGenerateEabKeyForIssuerResponse
from ahvac.models.pki_generate_eab_key_for_role_response import PkiGenerateEabKeyForRoleResponse
from ahvac.models.pki_generate_eab_key_response import PkiGenerateEabKeyResponse
from ahvac.models.pki_generate_exported_key_request import PkiGenerateExportedKeyRequest
from ahvac.models.pki_generate_exported_key_response import PkiGenerateExportedKeyResponse
from ahvac.models.pki_generate_intermediate_request import PkiGenerateIntermediateRequest
from ahvac.models.pki_generate_intermediate_response import PkiGenerateIntermediateResponse
from ahvac.models.pki_generate_internal_key_request import PkiGenerateInternalKeyRequest
from ahvac.models.pki_generate_internal_key_response import PkiGenerateInternalKeyResponse
from ahvac.models.pki_generate_kms_key_request import PkiGenerateKmsKeyRequest
from ahvac.models.pki_generate_kms_key_response import PkiGenerateKmsKeyResponse
from ahvac.models.pki_generate_root_request import PkiGenerateRootRequest
from ahvac.models.pki_generate_root_response import PkiGenerateRootResponse
from ahvac.models.pki_import_key_request import PkiImportKeyRequest
from ahvac.models.pki_import_key_response import PkiImportKeyResponse
from ahvac.models.pki_issue_with_role_request import PkiIssueWithRoleRequest
from ahvac.models.pki_issue_with_role_response import PkiIssueWithRoleResponse
from ahvac.models.pki_issuer_issue_with_role_request import PkiIssuerIssueWithRoleRequest
from ahvac.models.pki_issuer_issue_with_role_response import PkiIssuerIssueWithRoleResponse
from ahvac.models.pki_issuer_read_crl_delta_der_response import PkiIssuerReadCrlDeltaDerResponse
from ahvac.models.pki_issuer_read_crl_delta_pem_response import PkiIssuerReadCrlDeltaPemResponse
from ahvac.models.pki_issuer_read_crl_delta_response import PkiIssuerReadCrlDeltaResponse
from ahvac.models.pki_issuer_read_crl_der_response import PkiIssuerReadCrlDerResponse
from ahvac.models.pki_issuer_read_crl_pem_response import PkiIssuerReadCrlPemResponse
from ahvac.models.pki_issuer_read_crl_response import PkiIssuerReadCrlResponse
from ahvac.models.pki_issuer_resign_crls_request import PkiIssuerResignCrlsRequest
from ahvac.models.pki_issuer_resign_crls_response import PkiIssuerResignCrlsResponse
from ahvac.models.pki_issuer_sign_intermediate_request import PkiIssuerSignIntermediateRequest
from ahvac.models.pki_issuer_sign_intermediate_response import PkiIssuerSignIntermediateResponse
from ahvac.models.pki_issuer_sign_revocation_list_request import PkiIssuerSignRevocationListRequest
from ahvac.models.pki_issuer_sign_revocation_list_response import PkiIssuerSignRevocationListResponse
from ahvac.models.pki_issuer_sign_self_issued_request import PkiIssuerSignSelfIssuedRequest
from ahvac.models.pki_issuer_sign_self_issued_response import PkiIssuerSignSelfIssuedResponse
from ahvac.models.pki_issuer_sign_verbatim_request import PkiIssuerSignVerbatimRequest
from ahvac.models.pki_issuer_sign_verbatim_response import PkiIssuerSignVerbatimResponse
from ahvac.models.pki_issuer_sign_verbatim_with_role_request import PkiIssuerSignVerbatimWithRoleRequest
from ahvac.models.pki_issuer_sign_verbatim_with_role_response import PkiIssuerSignVerbatimWithRoleResponse
from ahvac.models.pki_issuer_sign_with_role_request import PkiIssuerSignWithRoleRequest
from ahvac.models.pki_issuer_sign_with_role_response import PkiIssuerSignWithRoleResponse
from ahvac.models.pki_issuers_generate_intermediate_request import PkiIssuersGenerateIntermediateRequest
from ahvac.models.pki_issuers_generate_intermediate_response import PkiIssuersGenerateIntermediateResponse
from ahvac.models.pki_issuers_generate_root_request import PkiIssuersGenerateRootRequest
from ahvac.models.pki_issuers_generate_root_response import PkiIssuersGenerateRootResponse
from ahvac.models.pki_issuers_import_bundle_request import PkiIssuersImportBundleRequest
from ahvac.models.pki_issuers_import_bundle_response import PkiIssuersImportBundleResponse
from ahvac.models.pki_issuers_import_cert_request import PkiIssuersImportCertRequest
from ahvac.models.pki_issuers_import_cert_response import PkiIssuersImportCertResponse
from ahvac.models.pki_list_eab_keys_response import PkiListEabKeysResponse
from ahvac.models.pki_list_issuers_response import PkiListIssuersResponse
from ahvac.models.pki_list_keys_response import PkiListKeysResponse
from ahvac.models.pki_patch_issuer_response import PkiPatchIssuerResponse
from ahvac.models.pki_patch_role_response import PkiPatchRoleResponse
from ahvac.models.pki_read_auto_tidy_configuration_response import PkiReadAutoTidyConfigurationResponse
from ahvac.models.pki_read_ca_chain_pem_response import PkiReadCaChainPemResponse
from ahvac.models.pki_read_ca_der_response import PkiReadCaDerResponse
from ahvac.models.pki_read_ca_pem_response import PkiReadCaPemResponse
from ahvac.models.pki_read_cert_ca_chain_response import PkiReadCertCaChainResponse
from ahvac.models.pki_read_cert_crl_response import PkiReadCertCrlResponse
from ahvac.models.pki_read_cert_delta_crl_response import PkiReadCertDeltaCrlResponse
from ahvac.models.pki_read_cert_raw_der_response import PkiReadCertRawDerResponse
from ahvac.models.pki_read_cert_raw_pem_response import PkiReadCertRawPemResponse
from ahvac.models.pki_read_cert_response import PkiReadCertResponse
from ahvac.models.pki_read_cluster_configuration_response import PkiReadClusterConfigurationResponse
from ahvac.models.pki_read_crl_configuration_response import PkiReadCrlConfigurationResponse
from ahvac.models.pki_read_crl_delta_pem_response import PkiReadCrlDeltaPemResponse
from ahvac.models.pki_read_crl_delta_response import PkiReadCrlDeltaResponse
from ahvac.models.pki_read_crl_der_response import PkiReadCrlDerResponse
from ahvac.models.pki_read_crl_pem_response import PkiReadCrlPemResponse
from ahvac.models.pki_read_issuer_der_response import PkiReadIssuerDerResponse
from ahvac.models.pki_read_issuer_json_response import PkiReadIssuerJsonResponse
from ahvac.models.pki_read_issuer_pem_response import PkiReadIssuerPemResponse
from ahvac.models.pki_read_issuer_response import PkiReadIssuerResponse
from ahvac.models.pki_read_issuers_configuration_response import PkiReadIssuersConfigurationResponse
from ahvac.models.pki_read_key_response import PkiReadKeyResponse
from ahvac.models.pki_read_keys_configuration_response import PkiReadKeysConfigurationResponse
from ahvac.models.pki_read_role_response import PkiReadRoleResponse
from ahvac.models.pki_read_urls_configuration_response import PkiReadUrlsConfigurationResponse
from ahvac.models.pki_replace_root_request import PkiReplaceRootRequest
from ahvac.models.pki_replace_root_response import PkiReplaceRootResponse
from ahvac.models.pki_revoke_issuer_response import PkiRevokeIssuerResponse
from ahvac.models.pki_revoke_request import PkiRevokeRequest
from ahvac.models.pki_revoke_response import PkiRevokeResponse
from ahvac.models.pki_revoke_with_key_request import PkiRevokeWithKeyRequest
from ahvac.models.pki_revoke_with_key_response import PkiRevokeWithKeyResponse
from ahvac.models.pki_root_sign_intermediate_request import PkiRootSignIntermediateRequest
from ahvac.models.pki_root_sign_intermediate_response import PkiRootSignIntermediateResponse
from ahvac.models.pki_root_sign_self_issued_request import PkiRootSignSelfIssuedRequest
from ahvac.models.pki_root_sign_self_issued_response import PkiRootSignSelfIssuedResponse
from ahvac.models.pki_rotate_crl_response import PkiRotateCrlResponse
from ahvac.models.pki_rotate_delta_crl_response import PkiRotateDeltaCrlResponse
from ahvac.models.pki_rotate_root_request import PkiRotateRootRequest
from ahvac.models.pki_rotate_root_response import PkiRotateRootResponse
from ahvac.models.pki_set_signed_intermediate_request import PkiSetSignedIntermediateRequest
from ahvac.models.pki_set_signed_intermediate_response import PkiSetSignedIntermediateResponse
from ahvac.models.pki_sign_verbatim_request import PkiSignVerbatimRequest
from ahvac.models.pki_sign_verbatim_response import PkiSignVerbatimResponse
from ahvac.models.pki_sign_verbatim_with_role_request import PkiSignVerbatimWithRoleRequest
from ahvac.models.pki_sign_verbatim_with_role_response import PkiSignVerbatimWithRoleResponse
from ahvac.models.pki_sign_with_role_request import PkiSignWithRoleRequest
from ahvac.models.pki_sign_with_role_response import PkiSignWithRoleResponse
from ahvac.models.pki_tidy_cancel_response import PkiTidyCancelResponse
from ahvac.models.pki_tidy_request import PkiTidyRequest
from ahvac.models.pki_tidy_status_response import PkiTidyStatusResponse
from ahvac.models.pki_write_acme_account_kid_request import PkiWriteAcmeAccountKidRequest
from ahvac.models.pki_write_acme_authorization_auth_id_request import PkiWriteAcmeAuthorizationAuthIdRequest
from ahvac.models.pki_write_acme_challenge_auth_id_challenge_type_request import PkiWriteAcmeChallengeAuthIdChallengeTypeRequest
from ahvac.models.pki_write_acme_new_account_request import PkiWriteAcmeNewAccountRequest
from ahvac.models.pki_write_acme_new_order_request import PkiWriteAcmeNewOrderRequest
from ahvac.models.pki_write_acme_order_order_id_cert_request import PkiWriteAcmeOrderOrderIdCertRequest
from ahvac.models.pki_write_acme_order_order_id_finalize_request import PkiWriteAcmeOrderOrderIdFinalizeRequest
from ahvac.models.pki_write_acme_order_order_id_request import PkiWriteAcmeOrderOrderIdRequest
from ahvac.models.pki_write_acme_orders_request import PkiWriteAcmeOrdersRequest
from ahvac.models.pki_write_acme_revoke_cert_request import PkiWriteAcmeRevokeCertRequest
from ahvac.models.pki_write_issuer_issuer_ref_acme_account_kid_request import PkiWriteIssuerIssuerRefAcmeAccountKidRequest
from ahvac.models.pki_write_issuer_issuer_ref_acme_authorization_auth_id_request import PkiWriteIssuerIssuerRefAcmeAuthorizationAuthIdRequest
from ahvac.models.pki_write_issuer_issuer_ref_acme_challenge_auth_id_challenge_type_request import PkiWriteIssuerIssuerRefAcmeChallengeAuthIdChallengeTypeRequest
from ahvac.models.pki_write_issuer_issuer_ref_acme_new_account_request import PkiWriteIssuerIssuerRefAcmeNewAccountRequest
from ahvac.models.pki_write_issuer_issuer_ref_acme_new_order_request import PkiWriteIssuerIssuerRefAcmeNewOrderRequest
from ahvac.models.pki_write_issuer_issuer_ref_acme_order_order_id_cert_request import PkiWriteIssuerIssuerRefAcmeOrderOrderIdCertRequest
from ahvac.models.pki_write_issuer_issuer_ref_acme_order_order_id_finalize_request import PkiWriteIssuerIssuerRefAcmeOrderOrderIdFinalizeRequest
from ahvac.models.pki_write_issuer_issuer_ref_acme_order_order_id_request import PkiWriteIssuerIssuerRefAcmeOrderOrderIdRequest
from ahvac.models.pki_write_issuer_issuer_ref_acme_orders_request import PkiWriteIssuerIssuerRefAcmeOrdersRequest
from ahvac.models.pki_write_issuer_issuer_ref_acme_revoke_cert_request import PkiWriteIssuerIssuerRefAcmeRevokeCertRequest
from ahvac.models.pki_write_issuer_issuer_ref_roles_role_acme_account_kid_request import PkiWriteIssuerIssuerRefRolesRoleAcmeAccountKidRequest
from ahvac.models.pki_write_issuer_issuer_ref_roles_role_acme_authorization_auth_id_request import PkiWriteIssuerIssuerRefRolesRoleAcmeAuthorizationAuthIdRequest
from ahvac.models.pki_write_issuer_issuer_ref_roles_role_acme_challenge_auth_id_challenge_type_request import PkiWriteIssuerIssuerRefRolesRoleAcmeChallengeAuthIdChallengeTypeRequest
from ahvac.models.pki_write_issuer_issuer_ref_roles_role_acme_new_account_request import PkiWriteIssuerIssuerRefRolesRoleAcmeNewAccountRequest
from ahvac.models.pki_write_issuer_issuer_ref_roles_role_acme_new_order_request import PkiWriteIssuerIssuerRefRolesRoleAcmeNewOrderRequest
from ahvac.models.pki_write_issuer_issuer_ref_roles_role_acme_order_order_id_cert_request import PkiWriteIssuerIssuerRefRolesRoleAcmeOrderOrderIdCertRequest
from ahvac.models.pki_write_issuer_issuer_ref_roles_role_acme_order_order_id_finalize_request import PkiWriteIssuerIssuerRefRolesRoleAcmeOrderOrderIdFinalizeRequest
from ahvac.models.pki_write_issuer_issuer_ref_roles_role_acme_order_order_id_request import PkiWriteIssuerIssuerRefRolesRoleAcmeOrderOrderIdRequest
from ahvac.models.pki_write_issuer_issuer_ref_roles_role_acme_orders_request import PkiWriteIssuerIssuerRefRolesRoleAcmeOrdersRequest
from ahvac.models.pki_write_issuer_issuer_ref_roles_role_acme_revoke_cert_request import PkiWriteIssuerIssuerRefRolesRoleAcmeRevokeCertRequest
from ahvac.models.pki_write_issuer_request import PkiWriteIssuerRequest
from ahvac.models.pki_write_issuer_response import PkiWriteIssuerResponse
from ahvac.models.pki_write_key_request import PkiWriteKeyRequest
from ahvac.models.pki_write_key_response import PkiWriteKeyResponse
from ahvac.models.pki_write_role_request import PkiWriteRoleRequest
from ahvac.models.pki_write_role_response import PkiWriteRoleResponse
from ahvac.models.pki_write_roles_role_acme_account_kid_request import PkiWriteRolesRoleAcmeAccountKidRequest
from ahvac.models.pki_write_roles_role_acme_authorization_auth_id_request import PkiWriteRolesRoleAcmeAuthorizationAuthIdRequest
from ahvac.models.pki_write_roles_role_acme_challenge_auth_id_challenge_type_request import PkiWriteRolesRoleAcmeChallengeAuthIdChallengeTypeRequest
from ahvac.models.pki_write_roles_role_acme_new_account_request import PkiWriteRolesRoleAcmeNewAccountRequest
from ahvac.models.pki_write_roles_role_acme_new_order_request import PkiWriteRolesRoleAcmeNewOrderRequest
from ahvac.models.pki_write_roles_role_acme_order_order_id_cert_request import PkiWriteRolesRoleAcmeOrderOrderIdCertRequest
from ahvac.models.pki_write_roles_role_acme_order_order_id_finalize_request import PkiWriteRolesRoleAcmeOrderOrderIdFinalizeRequest
from ahvac.models.pki_write_roles_role_acme_order_order_id_request import PkiWriteRolesRoleAcmeOrderOrderIdRequest
from ahvac.models.pki_write_roles_role_acme_orders_request import PkiWriteRolesRoleAcmeOrdersRequest
from ahvac.models.pki_write_roles_role_acme_revoke_cert_request import PkiWriteRolesRoleAcmeRevokeCertRequest
from ahvac.models.plugins_catalog_list_plugins_response import PluginsCatalogListPluginsResponse
from ahvac.models.plugins_catalog_list_plugins_with_type_response import PluginsCatalogListPluginsWithTypeResponse
from ahvac.models.plugins_catalog_read_plugin_configuration_response import PluginsCatalogReadPluginConfigurationResponse
from ahvac.models.plugins_catalog_read_plugin_configuration_with_type_response import PluginsCatalogReadPluginConfigurationWithTypeResponse
from ahvac.models.plugins_catalog_register_plugin_request import PluginsCatalogRegisterPluginRequest
from ahvac.models.plugins_catalog_register_plugin_with_type_request import PluginsCatalogRegisterPluginWithTypeRequest
from ahvac.models.plugins_reload_backends_request import PluginsReloadBackendsRequest
from ahvac.models.plugins_reload_backends_response import PluginsReloadBackendsResponse
from ahvac.models.plugins_runtimes_catalog_list_plugins_runtimes_response import PluginsRuntimesCatalogListPluginsRuntimesResponse
from ahvac.models.plugins_runtimes_catalog_read_plugin_runtime_configuration_response import PluginsRuntimesCatalogReadPluginRuntimeConfigurationResponse
from ahvac.models.plugins_runtimes_catalog_register_plugin_runtime_request import PluginsRuntimesCatalogRegisterPluginRuntimeRequest
from ahvac.models.policies_generate_password_from_password_policy_response import PoliciesGeneratePasswordFromPasswordPolicyResponse
from ahvac.models.policies_list_acl_policies2_response import PoliciesListAclPolicies2Response
from ahvac.models.policies_list_acl_policies3_response import PoliciesListAclPolicies3Response
from ahvac.models.policies_list_acl_policies_response import PoliciesListAclPoliciesResponse
from ahvac.models.policies_read_acl_policy2_response import PoliciesReadAclPolicy2Response
from ahvac.models.policies_read_acl_policy_response import PoliciesReadAclPolicyResponse
from ahvac.models.policies_read_password_policy_response import PoliciesReadPasswordPolicyResponse
from ahvac.models.policies_write_acl_policy2_request import PoliciesWriteAclPolicy2Request
from ahvac.models.policies_write_acl_policy_request import PoliciesWriteAclPolicyRequest
from ahvac.models.policies_write_password_policy_request import PoliciesWritePasswordPolicyRequest
from ahvac.models.query_token_accessor_capabilities_request import QueryTokenAccessorCapabilitiesRequest
from ahvac.models.query_token_capabilities_request import QueryTokenCapabilitiesRequest
from ahvac.models.query_token_self_capabilities_request import QueryTokenSelfCapabilitiesRequest
from ahvac.models.rabbit_mq_configure_connection_request import RabbitMqConfigureConnectionRequest
from ahvac.models.rabbit_mq_configure_lease_request import RabbitMqConfigureLeaseRequest
from ahvac.models.rabbit_mq_write_role_request import RabbitMqWriteRoleRequest
from ahvac.models.radius_configure_request import RadiusConfigureRequest
from ahvac.models.radius_login_request import RadiusLoginRequest
from ahvac.models.radius_login_with_username_request import RadiusLoginWithUsernameRequest
from ahvac.models.radius_write_user_request import RadiusWriteUserRequest
from ahvac.models.rate_limit_quotas_configure_request import RateLimitQuotasConfigureRequest
from ahvac.models.rate_limit_quotas_read_configuration_response import RateLimitQuotasReadConfigurationResponse
from ahvac.models.rate_limit_quotas_read_response import RateLimitQuotasReadResponse
from ahvac.models.rate_limit_quotas_write_request import RateLimitQuotasWriteRequest
from ahvac.models.raw_read_response import RawReadResponse
from ahvac.models.raw_write_request import RawWriteRequest
from ahvac.models.read_wrapping_properties2_response import ReadWrappingProperties2Response
from ahvac.models.read_wrapping_properties_request import ReadWrappingPropertiesRequest
from ahvac.models.read_wrapping_properties_response import ReadWrappingPropertiesResponse
from ahvac.models.rekey_attempt_initialize_request import RekeyAttemptInitializeRequest
from ahvac.models.rekey_attempt_initialize_response import RekeyAttemptInitializeResponse
from ahvac.models.rekey_attempt_read_progress_response import RekeyAttemptReadProgressResponse
from ahvac.models.rekey_attempt_update_request import RekeyAttemptUpdateRequest
from ahvac.models.rekey_attempt_update_response import RekeyAttemptUpdateResponse
from ahvac.models.rekey_read_backup_key_response import RekeyReadBackupKeyResponse
from ahvac.models.rekey_read_backup_recovery_key_response import RekeyReadBackupRecoveryKeyResponse
from ahvac.models.rekey_verification_cancel_response import RekeyVerificationCancelResponse
from ahvac.models.rekey_verification_read_progress_response import RekeyVerificationReadProgressResponse
from ahvac.models.rekey_verification_update_request import RekeyVerificationUpdateRequest
from ahvac.models.rekey_verification_update_response import RekeyVerificationUpdateResponse
from ahvac.models.remount_request import RemountRequest
from ahvac.models.remount_response import RemountResponse
from ahvac.models.remount_status_response import RemountStatusResponse
from ahvac.models.rewrap_request import RewrapRequest
from ahvac.models.root_token_generation_initialize2_request import RootTokenGenerationInitialize2Request
from ahvac.models.root_token_generation_initialize2_response import RootTokenGenerationInitialize2Response
from ahvac.models.root_token_generation_initialize_request import RootTokenGenerationInitializeRequest
from ahvac.models.root_token_generation_initialize_response import RootTokenGenerationInitializeResponse
from ahvac.models.root_token_generation_read_progress2_response import RootTokenGenerationReadProgress2Response
from ahvac.models.root_token_generation_read_progress_response import RootTokenGenerationReadProgressResponse
from ahvac.models.root_token_generation_update_request import RootTokenGenerationUpdateRequest
from ahvac.models.root_token_generation_update_response import RootTokenGenerationUpdateResponse
from ahvac.models.seal_status_response import SealStatusResponse
from ahvac.models.ssh_configure_ca_request import SshConfigureCaRequest
from ahvac.models.ssh_configure_zero_address_request import SshConfigureZeroAddressRequest
from ahvac.models.ssh_generate_credentials_request import SshGenerateCredentialsRequest
from ahvac.models.ssh_issue_certificate_request import SshIssueCertificateRequest
from ahvac.models.ssh_list_roles_by_ip_request import SshListRolesByIpRequest
from ahvac.models.ssh_sign_certificate_request import SshSignCertificateRequest
from ahvac.models.ssh_verify_otp_request import SshVerifyOtpRequest
from ahvac.models.ssh_write_role_request import SshWriteRoleRequest
from ahvac.models.standard_list_response import StandardListResponse
from ahvac.models.terraform_cloud_configure_request import TerraformCloudConfigureRequest
from ahvac.models.terraform_cloud_write_role_request import TerraformCloudWriteRoleRequest
from ahvac.models.token_create_against_role_request import TokenCreateAgainstRoleRequest
from ahvac.models.token_create_orphan_request import TokenCreateOrphanRequest
from ahvac.models.token_create_request import TokenCreateRequest
from ahvac.models.token_look_up_accessor_request import TokenLookUpAccessorRequest
from ahvac.models.token_look_up_request import TokenLookUpRequest
from ahvac.models.token_look_up_self2_request import TokenLookUpSelf2Request
from ahvac.models.token_renew_accessor_request import TokenRenewAccessorRequest
from ahvac.models.token_renew_request import TokenRenewRequest
from ahvac.models.token_renew_self_request import TokenRenewSelfRequest
from ahvac.models.token_revoke_accessor_request import TokenRevokeAccessorRequest
from ahvac.models.token_revoke_orphan_request import TokenRevokeOrphanRequest
from ahvac.models.token_revoke_request import TokenRevokeRequest
from ahvac.models.token_write_role_request import TokenWriteRoleRequest
from ahvac.models.totp_create_key_request import TotpCreateKeyRequest
from ahvac.models.totp_validate_code_request import TotpValidateCodeRequest
from ahvac.models.transit_configure_cache_request import TransitConfigureCacheRequest
from ahvac.models.transit_configure_key_request import TransitConfigureKeyRequest
from ahvac.models.transit_configure_keys_request import TransitConfigureKeysRequest
from ahvac.models.transit_create_key_request import TransitCreateKeyRequest
from ahvac.models.transit_decrypt_request import TransitDecryptRequest
from ahvac.models.transit_encrypt_request import TransitEncryptRequest
from ahvac.models.transit_generate_csr_for_key_request import TransitGenerateCsrForKeyRequest
from ahvac.models.transit_generate_data_key_request import TransitGenerateDataKeyRequest
from ahvac.models.transit_generate_hmac_request import TransitGenerateHmacRequest
from ahvac.models.transit_generate_hmac_with_algorithm_request import TransitGenerateHmacWithAlgorithmRequest
from ahvac.models.transit_generate_random_request import TransitGenerateRandomRequest
from ahvac.models.transit_generate_random_with_bytes_request import TransitGenerateRandomWithBytesRequest
from ahvac.models.transit_generate_random_with_source_and_bytes_request import TransitGenerateRandomWithSourceAndBytesRequest
from ahvac.models.transit_generate_random_with_source_request import TransitGenerateRandomWithSourceRequest
from ahvac.models.transit_hash_request import TransitHashRequest
from ahvac.models.transit_hash_with_algorithm_request import TransitHashWithAlgorithmRequest
from ahvac.models.transit_import_key_request import TransitImportKeyRequest
from ahvac.models.transit_import_key_version_request import TransitImportKeyVersionRequest
from ahvac.models.transit_restore_and_rename_key_request import TransitRestoreAndRenameKeyRequest
from ahvac.models.transit_restore_key_request import TransitRestoreKeyRequest
from ahvac.models.transit_rewrap_request import TransitRewrapRequest
from ahvac.models.transit_rotate_key_request import TransitRotateKeyRequest
from ahvac.models.transit_set_certificate_for_key_request import TransitSetCertificateForKeyRequest
from ahvac.models.transit_sign_request import TransitSignRequest
from ahvac.models.transit_sign_with_algorithm_request import TransitSignWithAlgorithmRequest
from ahvac.models.transit_trim_key_request import TransitTrimKeyRequest
from ahvac.models.transit_verify_request import TransitVerifyRequest
from ahvac.models.transit_verify_with_algorithm_request import TransitVerifyWithAlgorithmRequest
from ahvac.models.ui_headers_configure_request import UiHeadersConfigureRequest
from ahvac.models.ui_headers_list_response import UiHeadersListResponse
from ahvac.models.ui_headers_read_configuration_response import UiHeadersReadConfigurationResponse
from ahvac.models.unseal_request import UnsealRequest
from ahvac.models.unseal_response import UnsealResponse
from ahvac.models.unwrap_request import UnwrapRequest
from ahvac.models.userpass_login_request import UserpassLoginRequest
from ahvac.models.userpass_reset_password_request import UserpassResetPasswordRequest
from ahvac.models.userpass_update_policies_request import UserpassUpdatePoliciesRequest
from ahvac.models.userpass_write_user_request import UserpassWriteUserRequest
from ahvac.models.version_history_response import VersionHistoryResponse



# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class SshWriteRoleRequest(BaseModel):
    """
    SshWriteRoleRequest
    """ # noqa: E501
    algorithm_signer: Optional[StrictStr] = Field(default=None, description="[Not applicable for OTP type] [Optional for CA type] When supplied, this value specifies a signing algorithm for the key. Possible values: ssh-rsa, rsa-sha2-256, rsa-sha2-512, default, or the empty string.")
    allow_bare_domains: Optional[StrictBool] = Field(default=None, description="[Not applicable for OTP type] [Optional for CA type] If set, host certificates that are requested are allowed to use the base domains listed in \"allowed_domains\", e.g. \"example.com\". This is a separate option as in some cases this can be considered a security threat.")
    allow_host_certificates: Optional[StrictBool] = Field(default=False, description="[Not applicable for OTP type] [Optional for CA type] If set, certificates are allowed to be signed for use as a 'host'.")
    allow_subdomains: Optional[StrictBool] = Field(default=None, description="[Not applicable for OTP type] [Optional for CA type] If set, host certificates that are requested are allowed to use subdomains of those listed in \"allowed_domains\".")
    allow_user_certificates: Optional[StrictBool] = Field(default=False, description="[Not applicable for OTP type] [Optional for CA type] If set, certificates are allowed to be signed for use as a 'user'.")
    allow_user_key_ids: Optional[StrictBool] = Field(default=None, description="[Not applicable for OTP type] [Optional for CA type] If true, users can override the key ID for a signed certificate with the \"key_id\" field. When false, the key ID will always be the token display name. The key ID is logged by the SSH server and can be useful for auditing.")
    allowed_critical_options: Optional[StrictStr] = Field(default=None, description="[Not applicable for OTP type] [Optional for CA type] A comma-separated list of critical options that certificates can have when signed. To allow any critical options, set this to an empty string.")
    allowed_domains: Optional[StrictStr] = Field(default=None, description="[Not applicable for OTP type] [Optional for CA type] If this option is not specified, client can request for a signed certificate for any valid host. If only certain domains are allowed, then this list enforces it.")
    allowed_domains_template: Optional[StrictBool] = Field(default=False, description="[Not applicable for OTP type] [Optional for CA type] If set, Allowed domains can be specified using identity template policies. Non-templated domains are also permitted.")
    allowed_extensions: Optional[StrictStr] = Field(default=None, description="[Not applicable for OTP type] [Optional for CA type] A comma-separated list of extensions that certificates can have when signed. An empty list means that no extension overrides are allowed by an end-user; explicitly specify '*' to allow any extensions to be set.")
    allowed_user_key_lengths: Optional[Dict[str, Any]] = Field(default=None, description="[Not applicable for OTP type] [Optional for CA type] If set, allows the enforcement of key types and minimum key sizes to be signed.")
    allowed_users: Optional[StrictStr] = Field(default=None, description="[Optional for all types] [Works differently for CA type] If this option is not specified, or is '*', client can request a credential for any valid user at the remote host, including the admin user. If only certain usernames are to be allowed, then this list enforces it. If this field is set, then credentials can only be created for default_user and usernames present in this list. Setting this option will enable all the users with access to this role to fetch credentials for all other usernames in this list. Use with caution. N.B.: with the CA type, an empty list means that no users are allowed; explicitly specify '*' to allow any user.")
    allowed_users_template: Optional[StrictBool] = Field(default=False, description="[Not applicable for OTP type] [Optional for CA type] If set, Allowed users can be specified using identity template policies. Non-templated users are also permitted.")
    cidr_list: Optional[StrictStr] = Field(default=None, description="[Optional for OTP type] [Not applicable for CA type] Comma separated list of CIDR blocks for which the role is applicable for. CIDR blocks can belong to more than one role.")
    default_critical_options: Optional[Dict[str, Any]] = Field(default=None, description="[Not applicable for OTP type] [Optional for CA type] Critical options certificates should have if none are provided when signing. This field takes in key value pairs in JSON format. Note that these are not restricted by \"allowed_critical_options\". Defaults to none.")
    default_extensions: Optional[Dict[str, Any]] = Field(default=None, description="[Not applicable for OTP type] [Optional for CA type] Extensions certificates should have if none are provided when signing. This field takes in key value pairs in JSON format. Note that these are not restricted by \"allowed_extensions\". Defaults to none.")
    default_extensions_template: Optional[StrictBool] = Field(default=False, description="[Not applicable for OTP type] [Optional for CA type] If set, Default extension values can be specified using identity template policies. Non-templated extension values are also permitted.")
    default_user: Optional[StrictStr] = Field(default=None, description="[Required for OTP type] [Optional for CA type] Default username for which a credential will be generated. When the endpoint 'creds/' is used without a username, this value will be used as default username.")
    default_user_template: Optional[StrictBool] = Field(default=False, description="[Not applicable for OTP type] [Optional for CA type] If set, Default user can be specified using identity template policies. Non-templated users are also permitted.")
    exclude_cidr_list: Optional[StrictStr] = Field(default=None, description="[Optional for OTP type] [Not applicable for CA type] Comma separated list of CIDR blocks. IP addresses belonging to these blocks are not accepted by the role. This is particularly useful when big CIDR blocks are being used by the role and certain parts of it needs to be kept out.")
    key_id_format: Optional[StrictStr] = Field(default=None, description="[Not applicable for OTP type] [Optional for CA type] When supplied, this value specifies a custom format for the key id of a signed certificate. The following variables are available for use: '{{token_display_name}}' - The display name of the token used to make the request. '{{role_name}}' - The name of the role signing the request. '{{public_key_hash}}' - A SHA256 checksum of the public key that is being signed.")
    key_type: Optional[StrictStr] = Field(default=None, description="[Required for all types] Type of key used to login to hosts. It can be either 'otp' or 'ca'. 'otp' type requires agent to be installed in remote hosts.")
    max_ttl: Optional[StrictStr] = Field(default=None, description="[Not applicable for OTP type] [Optional for CA type] The maximum allowed lease duration")
    not_before_duration: Optional[StrictStr] = Field(default='30', description="[Not applicable for OTP type] [Optional for CA type] The duration that the SSH certificate should be backdated by at issuance.")
    port: Optional[StrictInt] = Field(default=None, description="[Optional for OTP type] [Not applicable for CA type] Port number for SSH connection. Default is '22'. Port number does not play any role in creation of OTP. For 'otp' type, this is just a way to inform client about the port number to use. Port number will be returned to client by Vault server along with OTP.")
    ttl: Optional[StrictStr] = Field(default=None, description="[Not applicable for OTP type] [Optional for CA type] The lease duration if no specific lease duration is requested. The lease duration controls the expiration of certificates issued by this backend. Defaults to the value of max_ttl.")
    __properties: ClassVar[List[str]] = ["algorithm_signer", "allow_bare_domains", "allow_host_certificates", "allow_subdomains", "allow_user_certificates", "allow_user_key_ids", "allowed_critical_options", "allowed_domains", "allowed_domains_template", "allowed_extensions", "allowed_user_key_lengths", "allowed_users", "allowed_users_template", "cidr_list", "default_critical_options", "default_extensions", "default_extensions_template", "default_user", "default_user_template", "exclude_cidr_list", "key_id_format", "key_type", "max_ttl", "not_before_duration", "port", "ttl"]

    @field_validator('algorithm_signer')
    def algorithm_signer_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['', 'default', 'ssh-rsa', 'rsa-sha2-256', 'rsa-sha2-512']):
            raise ValueError("must be one of enum values ('', 'default', 'ssh-rsa', 'rsa-sha2-256', 'rsa-sha2-512')")
        return value

    @field_validator('key_type')
    def key_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['otp', 'ca']):
            raise ValueError("must be one of enum values ('otp', 'ca')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SshWriteRoleRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SshWriteRoleRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "algorithm_signer": obj.get("algorithm_signer"),
            "allow_bare_domains": obj.get("allow_bare_domains"),
            "allow_host_certificates": obj.get("allow_host_certificates") if obj.get("allow_host_certificates") is not None else False,
            "allow_subdomains": obj.get("allow_subdomains"),
            "allow_user_certificates": obj.get("allow_user_certificates") if obj.get("allow_user_certificates") is not None else False,
            "allow_user_key_ids": obj.get("allow_user_key_ids"),
            "allowed_critical_options": obj.get("allowed_critical_options"),
            "allowed_domains": obj.get("allowed_domains"),
            "allowed_domains_template": obj.get("allowed_domains_template") if obj.get("allowed_domains_template") is not None else False,
            "allowed_extensions": obj.get("allowed_extensions"),
            "allowed_user_key_lengths": obj.get("allowed_user_key_lengths"),
            "allowed_users": obj.get("allowed_users"),
            "allowed_users_template": obj.get("allowed_users_template") if obj.get("allowed_users_template") is not None else False,
            "cidr_list": obj.get("cidr_list"),
            "default_critical_options": obj.get("default_critical_options"),
            "default_extensions": obj.get("default_extensions"),
            "default_extensions_template": obj.get("default_extensions_template") if obj.get("default_extensions_template") is not None else False,
            "default_user": obj.get("default_user"),
            "default_user_template": obj.get("default_user_template") if obj.get("default_user_template") is not None else False,
            "exclude_cidr_list": obj.get("exclude_cidr_list"),
            "key_id_format": obj.get("key_id_format"),
            "key_type": obj.get("key_type"),
            "max_ttl": obj.get("max_ttl"),
            "not_before_duration": obj.get("not_before_duration") if obj.get("not_before_duration") is not None else '30',
            "port": obj.get("port"),
            "ttl": obj.get("ttl")
        })
        return _obj





# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ahvac.models.google_cloud_kms_decrypt_request import GoogleCloudKmsDecryptRequest

class TestGoogleCloudKmsDecryptRequest(unittest.TestCase):
    """GoogleCloudKmsDecryptRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GoogleCloudKmsDecryptRequest:
        """Test GoogleCloudKmsDecryptRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GoogleCloudKmsDecryptRequest`
        """
        model = GoogleCloudKmsDecryptRequest()
        if include_optional:
            return GoogleCloudKmsDecryptRequest(
                additional_authenticated_data = '',
                ciphertext = '',
                key_version = 56
            )
        else:
            return GoogleCloudKmsDecryptRequest(
        )
        """

    def testGoogleCloudKmsDecryptRequest(self):
        """Test GoogleCloudKmsDecryptRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class DatabaseWriteStaticRoleRequest(BaseModel):
    """
    DatabaseWriteStaticRoleRequest
    """ # noqa: E501
    credential_config: Optional[Dict[str, Any]] = Field(default=None, description="The configuration for the given credential_type.")
    credential_type: Optional[StrictStr] = Field(default='password', description="The type of credential to manage. Options include: 'password', 'rsa_private_key'. Defaults to 'password'.")
    db_name: Optional[StrictStr] = Field(default=None, description="Name of the database this role acts on.")
    rotation_period: Optional[StrictStr] = Field(default=None, description="Period for automatic credential rotation of the given username. Not valid unless used with \"username\". Mutually exclusive with \"rotation_schedule.\"")
    rotation_schedule: Optional[StrictStr] = Field(default=None, description="Schedule for automatic credential rotation of the given username. Mutually exclusive with \"rotation_period.\"")
    rotation_statements: Optional[List[StrictStr]] = Field(default=None, description="Specifies the database statements to be executed to rotate the accounts credentials. Not every plugin type will support this functionality. See the plugin's API page for more information on support and formatting for this parameter.")
    rotation_window: Optional[StrictStr] = Field(default=None, description="The window of time in which rotations are allowed to occur starting from a given \"rotation_schedule\". Requires \"rotation_schedule\" to be specified")
    username: Optional[StrictStr] = Field(default=None, description="Name of the static user account for Vault to manage. Requires \"rotation_period\" to be specified")
    __properties: ClassVar[List[str]] = ["credential_config", "credential_type", "db_name", "rotation_period", "rotation_schedule", "rotation_statements", "rotation_window", "username"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of DatabaseWriteStaticRoleRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of DatabaseWriteStaticRoleRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "credential_config": obj.get("credential_config"),
            "credential_type": obj.get("credential_type") if obj.get("credential_type") is not None else 'password',
            "db_name": obj.get("db_name"),
            "rotation_period": obj.get("rotation_period"),
            "rotation_schedule": obj.get("rotation_schedule"),
            "rotation_statements": obj.get("rotation_statements"),
            "rotation_window": obj.get("rotation_window"),
            "username": obj.get("username")
        })
        return _obj





# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class MfaUpdateOktaMethodRequest(BaseModel):
    """
    MfaUpdateOktaMethodRequest
    """ # noqa: E501
    api_token: Optional[StrictStr] = Field(default=None, description="Okta API key.")
    base_url: Optional[StrictStr] = Field(default=None, description="The base domain to use for the Okta API. When not specified in the configuration, \"okta.com\" is used.")
    method_name: Optional[StrictStr] = Field(default=None, description="The unique name identifier for this MFA method.")
    org_name: Optional[StrictStr] = Field(default=None, description="Name of the organization to be used in the Okta API.")
    primary_email: Optional[StrictBool] = Field(default=None, description="If true, the username will only match the primary email for the account. Defaults to false.")
    production: Optional[StrictBool] = Field(default=None, description="(DEPRECATED) Use base_url instead.")
    username_format: Optional[StrictStr] = Field(default=None, description="A template string for mapping Identity names to MFA method names. Values to substitute should be placed in {{}}. For example, \"{{entity.name}}@example.com\". If blank, the Entity's name field will be used as-is.")
    __properties: ClassVar[List[str]] = ["api_token", "base_url", "method_name", "org_name", "primary_email", "production", "username_format"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of MfaUpdateOktaMethodRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of MfaUpdateOktaMethodRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "api_token": obj.get("api_token"),
            "base_url": obj.get("base_url"),
            "method_name": obj.get("method_name"),
            "org_name": obj.get("org_name"),
            "primary_email": obj.get("primary_email"),
            "production": obj.get("production"),
            "username_format": obj.get("username_format")
        })
        return _obj





# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class PkiGenerateIntermediateRequest(BaseModel):
    """
    PkiGenerateIntermediateRequest
    """ # noqa: E501
    add_basic_constraints: Optional[StrictBool] = Field(default=None, description="Whether to add a Basic Constraints extension with CA: true. Only needed as a workaround in some compatibility scenarios with Active Directory Certificate Services.")
    alt_names: Optional[StrictStr] = Field(default=None, description="The requested Subject Alternative Names, if any, in a comma-delimited list. May contain both DNS names and email addresses.")
    common_name: Optional[StrictStr] = Field(default=None, description="The requested common name; if you want more than one, specify the alternative names in the alt_names map. If not specified when signing, the common name will be taken from the CSR; other names must still be specified in alt_names or ip_sans.")
    country: Optional[List[StrictStr]] = Field(default=None, description="If set, Country will be set to this value.")
    exclude_cn_from_sans: Optional[StrictBool] = Field(default=False, description="If true, the Common Name will not be included in DNS or Email Subject Alternate Names. Defaults to false (CN is included).")
    format: Optional[StrictStr] = Field(default='pem', description="Format for returned data. Can be \"pem\", \"der\", or \"pem_bundle\". If \"pem_bundle\", any private key and issuing cert will be appended to the certificate pem. If \"der\", the value will be base64 encoded. Defaults to \"pem\".")
    ip_sans: Optional[List[StrictStr]] = Field(default=None, description="The requested IP SANs, if any, in a comma-delimited list")
    key_bits: Optional[StrictInt] = Field(default=0, description="The number of bits to use. Allowed values are 0 (universal default); with rsa key_type: 2048 (default), 3072, or 4096; with ec key_type: 224, 256 (default), 384, or 521; ignored with ed25519.")
    key_name: Optional[StrictStr] = Field(default=None, description="Provide a name to the generated or existing key, the name must be unique across all keys and not be the reserved value 'default'")
    key_ref: Optional[StrictStr] = Field(default='default', description="Reference to a existing key; either \"default\" for the configured default key, an identifier or the name assigned to the key.")
    key_type: Optional[StrictStr] = Field(default='rsa', description="The type of key to use; defaults to RSA. \"rsa\" \"ec\" and \"ed25519\" are the only valid values.")
    locality: Optional[List[StrictStr]] = Field(default=None, description="If set, Locality will be set to this value.")
    managed_key_id: Optional[StrictStr] = Field(default=None, description="The name of the managed key to use when the exported type is kms. When kms type is the key type, this field or managed_key_name is required. Ignored for other types.")
    managed_key_name: Optional[StrictStr] = Field(default=None, description="The name of the managed key to use when the exported type is kms. When kms type is the key type, this field or managed_key_id is required. Ignored for other types.")
    not_after: Optional[StrictStr] = Field(default=None, description="Set the not after field of the certificate with specified date value. The value format should be given in UTC format YYYY-MM-ddTHH:MM:SSZ")
    not_before_duration: Optional[StrictStr] = Field(default='30', description="The duration before now which the certificate needs to be backdated by.")
    organization: Optional[List[StrictStr]] = Field(default=None, description="If set, O (Organization) will be set to this value.")
    other_sans: Optional[List[StrictStr]] = Field(default=None, description="Requested other SANs, in an array with the format <oid>;UTF8:<utf8 string value> for each entry.")
    ou: Optional[List[StrictStr]] = Field(default=None, description="If set, OU (OrganizationalUnit) will be set to this value.")
    postal_code: Optional[List[StrictStr]] = Field(default=None, description="If set, Postal Code will be set to this value.")
    private_key_format: Optional[StrictStr] = Field(default='der', description="Format for the returned private key. Generally the default will be controlled by the \"format\" parameter as either base64-encoded DER or PEM-encoded DER. However, this can be set to \"pkcs8\" to have the returned private key contain base64-encoded pkcs8 or PEM-encoded pkcs8 instead. Defaults to \"der\".")
    province: Optional[List[StrictStr]] = Field(default=None, description="If set, Province will be set to this value.")
    serial_number: Optional[StrictStr] = Field(default=None, description="The Subject's requested serial number, if any. See RFC 4519 Section 2.31 'serialNumber' for a description of this field. If you want more than one, specify alternative names in the alt_names map using OID 2.5.4.5. This has no impact on the final certificate's Serial Number field.")
    signature_bits: Optional[StrictInt] = Field(default=0, description="The number of bits to use in the signature algorithm; accepts 256 for SHA-2-256, 384 for SHA-2-384, and 512 for SHA-2-512. Defaults to 0 to automatically detect based on key length (SHA-2-256 for RSA keys, and matching the curve size for NIST P-Curves).")
    street_address: Optional[List[StrictStr]] = Field(default=None, description="If set, Street Address will be set to this value.")
    ttl: Optional[StrictStr] = Field(default=None, description="The requested Time To Live for the certificate; sets the expiration date. If not specified the role default, backend default, or system default TTL is used, in that order. Cannot be larger than the mount max TTL. Note: this only has an effect when generating a CA cert or signing a CA cert, not when generating a CSR for an intermediate CA.")
    uri_sans: Optional[List[StrictStr]] = Field(default=None, description="The requested URI SANs, if any, in a comma-delimited list.")
    __properties: ClassVar[List[str]] = ["add_basic_constraints", "alt_names", "common_name", "country", "exclude_cn_from_sans", "format", "ip_sans", "key_bits", "key_name", "key_ref", "key_type", "locality", "managed_key_id", "managed_key_name", "not_after", "not_before_duration", "organization", "other_sans", "ou", "postal_code", "private_key_format", "province", "serial_number", "signature_bits", "street_address", "ttl", "uri_sans"]

    @field_validator('format')
    def format_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['pem', 'der', 'pem_bundle']):
            raise ValueError("must be one of enum values ('pem', 'der', 'pem_bundle')")
        return value

    @field_validator('key_type')
    def key_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['rsa', 'ec', 'ed25519']):
            raise ValueError("must be one of enum values ('rsa', 'ec', 'ed25519')")
        return value

    @field_validator('private_key_format')
    def private_key_format_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['', 'der', 'pem', 'pkcs8']):
            raise ValueError("must be one of enum values ('', 'der', 'pem', 'pkcs8')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PkiGenerateIntermediateRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PkiGenerateIntermediateRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "add_basic_constraints": obj.get("add_basic_constraints"),
            "alt_names": obj.get("alt_names"),
            "common_name": obj.get("common_name"),
            "country": obj.get("country"),
            "exclude_cn_from_sans": obj.get("exclude_cn_from_sans") if obj.get("exclude_cn_from_sans") is not None else False,
            "format": obj.get("format") if obj.get("format") is not None else 'pem',
            "ip_sans": obj.get("ip_sans"),
            "key_bits": obj.get("key_bits") if obj.get("key_bits") is not None else 0,
            "key_name": obj.get("key_name"),
            "key_ref": obj.get("key_ref") if obj.get("key_ref") is not None else 'default',
            "key_type": obj.get("key_type") if obj.get("key_type") is not None else 'rsa',
            "locality": obj.get("locality"),
            "managed_key_id": obj.get("managed_key_id"),
            "managed_key_name": obj.get("managed_key_name"),
            "not_after": obj.get("not_after"),
            "not_before_duration": obj.get("not_before_duration") if obj.get("not_before_duration") is not None else '30',
            "organization": obj.get("organization"),
            "other_sans": obj.get("other_sans"),
            "ou": obj.get("ou"),
            "postal_code": obj.get("postal_code"),
            "private_key_format": obj.get("private_key_format") if obj.get("private_key_format") is not None else 'der',
            "province": obj.get("province"),
            "serial_number": obj.get("serial_number"),
            "signature_bits": obj.get("signature_bits") if obj.get("signature_bits") is not None else 0,
            "street_address": obj.get("street_address"),
            "ttl": obj.get("ttl"),
            "uri_sans": obj.get("uri_sans")
        })
        return _obj





# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ahvac.models.transit_import_key_request import TransitImportKeyRequest

class TestTransitImportKeyRequest(unittest.TestCase):
    """TransitImportKeyRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TransitImportKeyRequest:
        """Test TransitImportKeyRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TransitImportKeyRequest`
        """
        model = TransitImportKeyRequest()
        if include_optional:
            return TransitImportKeyRequest(
                allow_plaintext_backup = True,
                allow_rotation = True,
                auto_rotate_period = '0',
                ciphertext = '',
                context = '',
                derived = True,
                exportable = True,
                hash_function = 'SHA256',
                public_key = '',
                type = 'aes256-gcm96'
            )
        else:
            return TransitImportKeyRequest(
        )
        """

    def testTransitImportKeyRequest(self):
        """Test TransitImportKeyRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class AwsLoginRequest(BaseModel):
    """
    AwsLoginRequest
    """ # noqa: E501
    iam_http_request_method: Optional[StrictStr] = Field(default=None, description="HTTP method to use for the AWS request when auth_type is iam. This must match what has been signed in the presigned request.")
    iam_request_body: Optional[StrictStr] = Field(default=None, description="Base64-encoded request body when auth_type is iam. This must match the request body included in the signature.")
    iam_request_headers: Optional[StrictStr] = Field(default=None, description="Key/value pairs of headers for use in the sts:GetCallerIdentity HTTP requests headers when auth_type is iam. Can be either a Base64-encoded, JSON-serialized string, or a JSON object of key/value pairs. This must at a minimum include the headers over which AWS has included a signature.")
    iam_request_url: Optional[StrictStr] = Field(default=None, description="Base64-encoded full URL against which to make the AWS request when using iam auth_type.")
    identity: Optional[StrictStr] = Field(default=None, description="Base64 encoded EC2 instance identity document. This needs to be supplied along with the 'signature' parameter. If using 'curl' for fetching the identity document, consider using the option '-w 0' while piping the output to 'base64' binary.")
    nonce: Optional[StrictStr] = Field(default=None, description="The nonce to be used for subsequent login requests when auth_type is ec2. If this parameter is not specified at all and if reauthentication is allowed, then the backend will generate a random nonce, attaches it to the instance's identity access list entry and returns the nonce back as part of auth metadata. This value should be used with further login requests, to establish client authenticity. Clients can choose to set a custom nonce if preferred, in which case, it is recommended that clients provide a strong nonce. If a nonce is provided but with an empty value, it indicates intent to disable reauthentication. Note that, when 'disallow_reauthentication' option is enabled on either the role or the role tag, the 'nonce' holds no significance.")
    pkcs7: Optional[StrictStr] = Field(default=None, description="PKCS7 signature of the identity document when using an auth_type of ec2.")
    role: Optional[StrictStr] = Field(default=None, description="Name of the role against which the login is being attempted. If 'role' is not specified, then the login endpoint looks for a role bearing the name of the AMI ID of the EC2 instance that is trying to login. If a matching role is not found, login fails.")
    signature: Optional[StrictStr] = Field(default=None, description="Base64 encoded SHA256 RSA signature of the instance identity document. This needs to be supplied along with 'identity' parameter.")
    __properties: ClassVar[List[str]] = ["iam_http_request_method", "iam_request_body", "iam_request_headers", "iam_request_url", "identity", "nonce", "pkcs7", "role", "signature"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AwsLoginRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AwsLoginRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "iam_http_request_method": obj.get("iam_http_request_method"),
            "iam_request_body": obj.get("iam_request_body"),
            "iam_request_headers": obj.get("iam_request_headers"),
            "iam_request_url": obj.get("iam_request_url"),
            "identity": obj.get("identity"),
            "nonce": obj.get("nonce"),
            "pkcs7": obj.get("pkcs7"),
            "role": obj.get("role"),
            "signature": obj.get("signature")
        })
        return _obj





# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class PkiConfigureCrlResponse(BaseModel):
    """
    PkiConfigureCrlResponse
    """ # noqa: E501
    auto_rebuild: Optional[StrictBool] = Field(default=None, description="If set to true, enables automatic rebuilding of the CRL")
    auto_rebuild_grace_period: Optional[StrictStr] = Field(default='12h', description="The time before the CRL expires to automatically rebuild it, when enabled. Must be shorter than the CRL expiry. Defaults to 12h.")
    cross_cluster_revocation: Optional[StrictBool] = Field(default=None, description="Whether to enable a global, cross-cluster revocation queue. Must be used with auto_rebuild=true.")
    delta_rebuild_interval: Optional[StrictStr] = Field(default='15m', description="The time between delta CRL rebuilds if a new revocation has occurred. Must be shorter than the CRL expiry. Defaults to 15m.")
    disable: Optional[StrictBool] = Field(default=None, description="If set to true, disables generating the CRL entirely.")
    enable_delta: Optional[StrictBool] = Field(default=None, description="Whether to enable delta CRLs between authoritative CRL rebuilds")
    expiry: Optional[StrictStr] = Field(default='72h', description="The amount of time the generated CRL should be valid; defaults to 72 hours")
    ocsp_disable: Optional[StrictBool] = Field(default=None, description="If set to true, ocsp unauthorized responses will be returned.")
    ocsp_expiry: Optional[StrictStr] = Field(default='1h', description="The amount of time an OCSP response will be valid (controls the NextUpdate field); defaults to 12 hours")
    unified_crl: Optional[StrictBool] = Field(default=None, description="If set to true enables global replication of revocation entries, also enabling unified versions of OCSP and CRLs if their respective features are enabled. disable for CRLs and ocsp_disable for OCSP.")
    unified_crl_on_existing_paths: Optional[StrictBool] = Field(default=None, description="If set to true, existing CRL and OCSP paths will return the unified CRL instead of a response based on cluster-local data")
    __properties: ClassVar[List[str]] = ["auto_rebuild", "auto_rebuild_grace_period", "cross_cluster_revocation", "delta_rebuild_interval", "disable", "enable_delta", "expiry", "ocsp_disable", "ocsp_expiry", "unified_crl", "unified_crl_on_existing_paths"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PkiConfigureCrlResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PkiConfigureCrlResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "auto_rebuild": obj.get("auto_rebuild"),
            "auto_rebuild_grace_period": obj.get("auto_rebuild_grace_period") if obj.get("auto_rebuild_grace_period") is not None else '12h',
            "cross_cluster_revocation": obj.get("cross_cluster_revocation"),
            "delta_rebuild_interval": obj.get("delta_rebuild_interval") if obj.get("delta_rebuild_interval") is not None else '15m',
            "disable": obj.get("disable"),
            "enable_delta": obj.get("enable_delta"),
            "expiry": obj.get("expiry") if obj.get("expiry") is not None else '72h',
            "ocsp_disable": obj.get("ocsp_disable"),
            "ocsp_expiry": obj.get("ocsp_expiry") if obj.get("ocsp_expiry") is not None else '1h',
            "unified_crl": obj.get("unified_crl"),
            "unified_crl_on_existing_paths": obj.get("unified_crl_on_existing_paths")
        })
        return _obj





# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ahvac.models.kerberos_configure_ldap_request import KerberosConfigureLdapRequest

class TestKerberosConfigureLdapRequest(unittest.TestCase):
    """KerberosConfigureLdapRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> KerberosConfigureLdapRequest:
        """Test KerberosConfigureLdapRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `KerberosConfigureLdapRequest`
        """
        model = KerberosConfigureLdapRequest()
        if include_optional:
            return KerberosConfigureLdapRequest(
                anonymous_group_search = True,
                binddn = '',
                bindpass = '',
                case_sensitive_names = True,
                certificate = '',
                client_tls_cert = '',
                client_tls_key = '',
                connection_timeout = '30s',
                deny_null_bind = True,
                dereference_aliases = 'never',
                discoverdn = True,
                groupattr = 'cn',
                groupdn = '',
                groupfilter = '(|(memberUid={{.Username}})(member={{.UserDN}})(uniqueMember={{.UserDN}}))',
                insecure_tls = True,
                max_page_size = 56,
                request_timeout = '90s',
                starttls = True,
                tls_max_version = 'tls12',
                tls_min_version = 'tls12',
                token_bound_cidrs = [
                    ''
                    ],
                token_explicit_max_ttl = '',
                token_max_ttl = '',
                token_no_default_policy = True,
                token_num_uses = 56,
                token_period = '',
                token_policies = [
                    ''
                    ],
                token_ttl = '',
                token_type = 'default-service',
                upndomain = '',
                url = 'ldap://127.0.0.1',
                use_pre111_group_cn_behavior = True,
                use_token_groups = True,
                userattr = 'cn',
                userdn = '',
                userfilter = '({{.UserAttr}}={{.Username}})',
                username_as_alias = True
            )
        else:
            return KerberosConfigureLdapRequest(
        )
        """

    def testKerberosConfigureLdapRequest(self):
        """Test KerberosConfigureLdapRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class CertWriteCertificateRequest(BaseModel):
    """
    CertWriteCertificateRequest
    """ # noqa: E501
    allowed_common_names: Optional[List[StrictStr]] = Field(default=None, description="A comma-separated list of names. At least one must exist in the Common Name. Supports globbing.")
    allowed_dns_sans: Optional[List[StrictStr]] = Field(default=None, description="A comma-separated list of DNS names. At least one must exist in the SANs. Supports globbing.")
    allowed_email_sans: Optional[List[StrictStr]] = Field(default=None, description="A comma-separated list of Email Addresses. At least one must exist in the SANs. Supports globbing.")
    allowed_metadata_extensions: Optional[List[StrictStr]] = Field(default=None, description="A comma-separated string or array of oid extensions. Upon successful authentication, these extensions will be added as metadata if they are present in the certificate. The metadata key will be the string consisting of the oid numbers separated by a dash (-) instead of a dot (.) to allow usage in ACL templates.")
    allowed_names: Optional[List[StrictStr]] = Field(default=None, description="A comma-separated list of names. At least one must exist in either the Common Name or SANs. Supports globbing. This parameter is deprecated, please use allowed_common_names, allowed_dns_sans, allowed_email_sans, allowed_uri_sans.")
    allowed_organizational_units: Optional[List[StrictStr]] = Field(default=None, description="A comma-separated list of Organizational Units names. At least one must exist in the OU field.")
    allowed_uri_sans: Optional[List[StrictStr]] = Field(default=None, description="A comma-separated list of URIs. At least one must exist in the SANs. Supports globbing.")
    bound_cidrs: Optional[List[StrictStr]] = Field(default=None, description="Use \"token_bound_cidrs\" instead. If this and \"token_bound_cidrs\" are both specified, only \"token_bound_cidrs\" will be used.")
    certificate: Optional[StrictStr] = Field(default=None, description="The public certificate that should be trusted. Must be x509 PEM encoded.")
    display_name: Optional[StrictStr] = Field(default=None, description="The display name to use for clients using this certificate.")
    lease: Optional[StrictInt] = Field(default=None, description="Use \"token_ttl\" instead. If this and \"token_ttl\" are both specified, only \"token_ttl\" will be used.")
    max_ttl: Optional[StrictStr] = Field(default=None, description="Use \"token_max_ttl\" instead. If this and \"token_max_ttl\" are both specified, only \"token_max_ttl\" will be used.")
    ocsp_ca_certificates: Optional[StrictStr] = Field(default=None, description="Any additional CA certificates needed to communicate with OCSP servers")
    ocsp_enabled: Optional[StrictBool] = Field(default=None, description="Whether to attempt OCSP verification of certificates at login")
    ocsp_fail_open: Optional[StrictBool] = Field(default=False, description="If set to true, if an OCSP revocation cannot be made successfully, login will proceed rather than failing. If false, failing to get an OCSP status fails the request.")
    ocsp_query_all_servers: Optional[StrictBool] = Field(default=False, description="If set to true, rather than accepting the first successful OCSP response, query all servers and consider the certificate valid only if all servers agree.")
    ocsp_servers_override: Optional[List[StrictStr]] = Field(default=None, description="A comma-separated list of OCSP server addresses. If unset, the OCSP server is determined from the AuthorityInformationAccess extension on the certificate being inspected.")
    period: Optional[StrictStr] = Field(default=None, description="Use \"token_period\" instead. If this and \"token_period\" are both specified, only \"token_period\" will be used.")
    policies: Optional[List[StrictStr]] = Field(default=None, description="Use \"token_policies\" instead. If this and \"token_policies\" are both specified, only \"token_policies\" will be used.")
    required_extensions: Optional[List[StrictStr]] = Field(default=None, description="A comma-separated string or array of extensions formatted as \"oid:value\". Expects the extension value to be some type of ASN1 encoded string. All values much match. Supports globbing on \"value\".")
    token_bound_cidrs: Optional[List[StrictStr]] = Field(default=None, description="Comma separated string or JSON list of CIDR blocks. If set, specifies the blocks of IP addresses which are allowed to use the generated token.")
    token_explicit_max_ttl: Optional[StrictStr] = Field(default=None, description="If set, tokens created via this role carry an explicit maximum TTL. During renewal, the current maximum TTL values of the role and the mount are not checked for changes, and any updates to these values will have no effect on the token being renewed.")
    token_max_ttl: Optional[StrictStr] = Field(default=None, description="The maximum lifetime of the generated token")
    token_no_default_policy: Optional[StrictBool] = Field(default=None, description="If true, the 'default' policy will not automatically be added to generated tokens")
    token_num_uses: Optional[StrictInt] = Field(default=None, description="The maximum number of times a token may be used, a value of zero means unlimited")
    token_period: Optional[StrictStr] = Field(default=None, description="If set, tokens created via this role will have no max lifetime; instead, their renewal period will be fixed to this value. This takes an integer number of seconds, or a string duration (e.g. \"24h\").")
    token_policies: Optional[List[StrictStr]] = Field(default=None, description="Comma-separated list of policies")
    token_ttl: Optional[StrictStr] = Field(default=None, description="The initial ttl of the token to generate")
    token_type: Optional[StrictStr] = Field(default='default-service', description="The type of token to generate, service or batch")
    ttl: Optional[StrictStr] = Field(default=None, description="Use \"token_ttl\" instead. If this and \"token_ttl\" are both specified, only \"token_ttl\" will be used.")
    __properties: ClassVar[List[str]] = ["allowed_common_names", "allowed_dns_sans", "allowed_email_sans", "allowed_metadata_extensions", "allowed_names", "allowed_organizational_units", "allowed_uri_sans", "bound_cidrs", "certificate", "display_name", "lease", "max_ttl", "ocsp_ca_certificates", "ocsp_enabled", "ocsp_fail_open", "ocsp_query_all_servers", "ocsp_servers_override", "period", "policies", "required_extensions", "token_bound_cidrs", "token_explicit_max_ttl", "token_max_ttl", "token_no_default_policy", "token_num_uses", "token_period", "token_policies", "token_ttl", "token_type", "ttl"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CertWriteCertificateRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CertWriteCertificateRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "allowed_common_names": obj.get("allowed_common_names"),
            "allowed_dns_sans": obj.get("allowed_dns_sans"),
            "allowed_email_sans": obj.get("allowed_email_sans"),
            "allowed_metadata_extensions": obj.get("allowed_metadata_extensions"),
            "allowed_names": obj.get("allowed_names"),
            "allowed_organizational_units": obj.get("allowed_organizational_units"),
            "allowed_uri_sans": obj.get("allowed_uri_sans"),
            "bound_cidrs": obj.get("bound_cidrs"),
            "certificate": obj.get("certificate"),
            "display_name": obj.get("display_name"),
            "lease": obj.get("lease"),
            "max_ttl": obj.get("max_ttl"),
            "ocsp_ca_certificates": obj.get("ocsp_ca_certificates"),
            "ocsp_enabled": obj.get("ocsp_enabled"),
            "ocsp_fail_open": obj.get("ocsp_fail_open") if obj.get("ocsp_fail_open") is not None else False,
            "ocsp_query_all_servers": obj.get("ocsp_query_all_servers") if obj.get("ocsp_query_all_servers") is not None else False,
            "ocsp_servers_override": obj.get("ocsp_servers_override"),
            "period": obj.get("period"),
            "policies": obj.get("policies"),
            "required_extensions": obj.get("required_extensions"),
            "token_bound_cidrs": obj.get("token_bound_cidrs"),
            "token_explicit_max_ttl": obj.get("token_explicit_max_ttl"),
            "token_max_ttl": obj.get("token_max_ttl"),
            "token_no_default_policy": obj.get("token_no_default_policy"),
            "token_num_uses": obj.get("token_num_uses"),
            "token_period": obj.get("token_period"),
            "token_policies": obj.get("token_policies"),
            "token_ttl": obj.get("token_ttl"),
            "token_type": obj.get("token_type") if obj.get("token_type") is not None else 'default-service',
            "ttl": obj.get("ttl")
        })
        return _obj





# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class GoogleCloudWriteRoleRequest(BaseModel):
    """
    GoogleCloudWriteRoleRequest
    """ # noqa: E501
    add_group_aliases: Optional[StrictBool] = Field(default=False, description="If true, will add group aliases to auth tokens generated under this role. This will add the full list of ancestors (projects, folders, organizations) for the given entity's project. Requires IAM permission `resourcemanager.projects.get` on this project.")
    allow_gce_inference: Optional[StrictBool] = Field(default=True, description="'iam' roles only. If false, Vault will not not allow GCE instances to login in against this role")
    bound_instance_group: Optional[StrictStr] = Field(default=None, description="Deprecated: use \"bound_instance_groups\" instead.")
    bound_instance_groups: Optional[List[StrictStr]] = Field(default=None, description="Comma-separated list of permitted instance groups to which the GCE instance must belong. This option only applies to \"gce\" roles.")
    bound_labels: Optional[List[StrictStr]] = Field(default=None, description="Comma-separated list of GCP labels formatted as\"key:value\" strings that must be present on the GCE instance in order to authenticate. This option only applies to \"gce\" roles.")
    bound_projects: Optional[List[StrictStr]] = Field(default=None, description="GCP Projects that authenticating entities must belong to.")
    bound_region: Optional[StrictStr] = Field(default=None, description="Deprecated: use \"bound_regions\" instead.")
    bound_regions: Optional[List[StrictStr]] = Field(default=None, description="Comma-separated list of permitted regions to which the GCE instance must belong. If a group is provided, it is assumed to be a regional group. If \"zone\" is provided, this option is ignored. This can be a self-link or region name. This option only applies to \"gce\" roles.")
    bound_service_accounts: Optional[List[StrictStr]] = Field(default=None, description="Can be set for both 'iam' and 'gce' roles (required for 'iam'). A comma-seperated list of authorized service accounts. If the single value \"*\" is given, this is assumed to be all service accounts under the role's project. If this is set on a GCE role, the inferred service account from the instance metadata token will be used.")
    bound_zone: Optional[StrictStr] = Field(default=None, description="Deprecated: use \"bound_zones\" instead.")
    bound_zones: Optional[List[StrictStr]] = Field(default=None, description="Comma-separated list of permitted zones to which the GCE instance must belong. If a group is provided, it is assumed to be a zonal group. This can be a self-link or zone name. This option only applies to \"gce\" roles.")
    max_jwt_exp: Optional[StrictStr] = Field(default='900', description="Currently enabled for 'iam' only. Duration in seconds from time of validation that a JWT must expire within.")
    max_ttl: Optional[StrictStr] = Field(default=None, description="Use \"token_max_ttl\" instead. If this and \"token_max_ttl\" are both specified, only \"token_max_ttl\" will be used.")
    period: Optional[StrictStr] = Field(default=None, description="Use \"token_period\" instead. If this and \"token_period\" are both specified, only \"token_period\" will be used.")
    policies: Optional[List[StrictStr]] = Field(default=None, description="Use \"token_policies\" instead. If this and \"token_policies\" are both specified, only \"token_policies\" will be used.")
    project_id: Optional[StrictStr] = Field(default=None, description="Deprecated: use \"bound_projects\" instead")
    service_accounts: Optional[List[StrictStr]] = Field(default=None, description="Deprecated: use \"bound_service_accounts\" instead.")
    token_bound_cidrs: Optional[List[StrictStr]] = Field(default=None, description="Comma separated string or JSON list of CIDR blocks. If set, specifies the blocks of IP addresses which are allowed to use the generated token.")
    token_explicit_max_ttl: Optional[StrictStr] = Field(default=None, description="If set, tokens created via this role carry an explicit maximum TTL. During renewal, the current maximum TTL values of the role and the mount are not checked for changes, and any updates to these values will have no effect on the token being renewed.")
    token_max_ttl: Optional[StrictStr] = Field(default=None, description="The maximum lifetime of the generated token")
    token_no_default_policy: Optional[StrictBool] = Field(default=None, description="If true, the 'default' policy will not automatically be added to generated tokens")
    token_num_uses: Optional[StrictInt] = Field(default=None, description="The maximum number of times a token may be used, a value of zero means unlimited")
    token_period: Optional[StrictStr] = Field(default=None, description="If set, tokens created via this role will have no max lifetime; instead, their renewal period will be fixed to this value. This takes an integer number of seconds, or a string duration (e.g. \"24h\").")
    token_policies: Optional[List[StrictStr]] = Field(default=None, description="Comma-separated list of policies")
    token_ttl: Optional[StrictStr] = Field(default=None, description="The initial ttl of the token to generate")
    token_type: Optional[StrictStr] = Field(default='default-service', description="The type of token to generate, service or batch")
    ttl: Optional[StrictStr] = Field(default=None, description="Use \"token_ttl\" instead. If this and \"token_ttl\" are both specified, only \"token_ttl\" will be used.")
    type: Optional[StrictStr] = Field(default=None, description="Type of the role. Currently supported: iam, gce")
    __properties: ClassVar[List[str]] = ["add_group_aliases", "allow_gce_inference", "bound_instance_group", "bound_instance_groups", "bound_labels", "bound_projects", "bound_region", "bound_regions", "bound_service_accounts", "bound_zone", "bound_zones", "max_jwt_exp", "max_ttl", "period", "policies", "project_id", "service_accounts", "token_bound_cidrs", "token_explicit_max_ttl", "token_max_ttl", "token_no_default_policy", "token_num_uses", "token_period", "token_policies", "token_ttl", "token_type", "ttl", "type"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of GoogleCloudWriteRoleRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of GoogleCloudWriteRoleRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "add_group_aliases": obj.get("add_group_aliases") if obj.get("add_group_aliases") is not None else False,
            "allow_gce_inference": obj.get("allow_gce_inference") if obj.get("allow_gce_inference") is not None else True,
            "bound_instance_group": obj.get("bound_instance_group"),
            "bound_instance_groups": obj.get("bound_instance_groups"),
            "bound_labels": obj.get("bound_labels"),
            "bound_projects": obj.get("bound_projects"),
            "bound_region": obj.get("bound_region"),
            "bound_regions": obj.get("bound_regions"),
            "bound_service_accounts": obj.get("bound_service_accounts"),
            "bound_zone": obj.get("bound_zone"),
            "bound_zones": obj.get("bound_zones"),
            "max_jwt_exp": obj.get("max_jwt_exp") if obj.get("max_jwt_exp") is not None else '900',
            "max_ttl": obj.get("max_ttl"),
            "period": obj.get("period"),
            "policies": obj.get("policies"),
            "project_id": obj.get("project_id"),
            "service_accounts": obj.get("service_accounts"),
            "token_bound_cidrs": obj.get("token_bound_cidrs"),
            "token_explicit_max_ttl": obj.get("token_explicit_max_ttl"),
            "token_max_ttl": obj.get("token_max_ttl"),
            "token_no_default_policy": obj.get("token_no_default_policy"),
            "token_num_uses": obj.get("token_num_uses"),
            "token_period": obj.get("token_period"),
            "token_policies": obj.get("token_policies"),
            "token_ttl": obj.get("token_ttl"),
            "token_type": obj.get("token_type") if obj.get("token_type") is not None else 'default-service',
            "ttl": obj.get("ttl"),
            "type": obj.get("type")
        })
        return _obj





# flake8: noqa

# import apis into api package
from ahvac.api.auth_api import AuthApi
from ahvac.api.identity_api import IdentityApi
from ahvac.api.secrets_api import SecretsApi
from ahvac.api.system_api import SystemApi




# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class EntityMergeRequest(BaseModel):
    """
    EntityMergeRequest
    """ # noqa: E501
    conflicting_alias_ids_to_keep: Optional[List[StrictStr]] = Field(default=None, description="Alias IDs to keep in case of conflicting aliases. Ignored if no conflicting aliases found")
    force: Optional[StrictBool] = Field(default=None, description="Setting this will follow the 'mine' strategy for merging MFA secrets. If there are secrets of the same type both in entities that are merged from and in entity into which all others are getting merged, secrets in the destination will be unaltered. If not set, this API will throw an error containing all the conflicts.")
    from_entity_ids: Optional[List[StrictStr]] = Field(default=None, description="Entity IDs which need to get merged")
    to_entity_id: Optional[StrictStr] = Field(default=None, description="Entity ID into which all the other entities need to get merged")
    __properties: ClassVar[List[str]] = ["conflicting_alias_ids_to_keep", "force", "from_entity_ids", "to_entity_id"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of EntityMergeRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of EntityMergeRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "conflicting_alias_ids_to_keep": obj.get("conflicting_alias_ids_to_keep"),
            "force": obj.get("force"),
            "from_entity_ids": obj.get("from_entity_ids"),
            "to_entity_id": obj.get("to_entity_id")
        })
        return _obj





# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class AwsWriteRoleTagRequest(BaseModel):
    """
    AwsWriteRoleTagRequest
    """ # noqa: E501
    allow_instance_migration: Optional[StrictBool] = Field(default=False, description="If set, allows migration of the underlying instance where the client resides. This keys off of pendingTime in the metadata document, so essentially, this disables the client nonce check whenever the instance is migrated to a new host and pendingTime is newer than the previously-remembered time. Use with caution.")
    disallow_reauthentication: Optional[StrictBool] = Field(default=False, description="If set, only allows a single token to be granted per instance ID. In order to perform a fresh login, the entry in access list for the instance ID needs to be cleared using the 'auth/aws-ec2/identity-accesslist/<instance_id>' endpoint.")
    instance_id: Optional[StrictStr] = Field(default=None, description="Instance ID for which this tag is intended for. If set, the created tag can only be used by the instance with the given ID.")
    max_ttl: Optional[StrictStr] = Field(default='0', description="If set, specifies the maximum allowed token lifetime.")
    policies: Optional[List[StrictStr]] = Field(default=None, description="Policies to be associated with the tag. If set, must be a subset of the role's policies. If set, but set to an empty value, only the 'default' policy will be given to issued tokens.")
    __properties: ClassVar[List[str]] = ["allow_instance_migration", "disallow_reauthentication", "instance_id", "max_ttl", "policies"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AwsWriteRoleTagRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AwsWriteRoleTagRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "allow_instance_migration": obj.get("allow_instance_migration") if obj.get("allow_instance_migration") is not None else False,
            "disallow_reauthentication": obj.get("disallow_reauthentication") if obj.get("disallow_reauthentication") is not None else False,
            "instance_id": obj.get("instance_id"),
            "max_ttl": obj.get("max_ttl") if obj.get("max_ttl") is not None else '0',
            "policies": obj.get("policies")
        })
        return _obj





# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class TokenCreateAgainstRoleRequest(BaseModel):
    """
    TokenCreateAgainstRoleRequest
    """ # noqa: E501
    display_name: Optional[StrictStr] = Field(default=None, description="Name to associate with this token")
    entity_alias: Optional[StrictStr] = Field(default=None, description="Name of the entity alias to associate with this token")
    explicit_max_ttl: Optional[StrictStr] = Field(default=None, description="Explicit Max TTL of this token")
    id: Optional[StrictStr] = Field(default=None, description="Value for the token")
    lease: Optional[StrictStr] = Field(default=None, description="Use 'ttl' instead")
    meta: Optional[Dict[str, Any]] = Field(default=None, description="Arbitrary key=value metadata to associate with the token")
    no_default_policy: Optional[StrictBool] = Field(default=None, description="Do not include default policy for this token")
    no_parent: Optional[StrictBool] = Field(default=None, description="Create the token with no parent")
    num_uses: Optional[StrictInt] = Field(default=None, description="Max number of uses for this token")
    period: Optional[StrictStr] = Field(default=None, description="Renew period")
    policies: Optional[List[StrictStr]] = Field(default=None, description="List of policies for the token")
    renewable: Optional[StrictBool] = Field(default=True, description="Allow token to be renewed past its initial TTL up to system/mount maximum TTL")
    ttl: Optional[StrictStr] = Field(default=None, description="Time to live for this token")
    type: Optional[StrictStr] = Field(default=None, description="Token type")
    __properties: ClassVar[List[str]] = ["display_name", "entity_alias", "explicit_max_ttl", "id", "lease", "meta", "no_default_policy", "no_parent", "num_uses", "period", "policies", "renewable", "ttl", "type"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TokenCreateAgainstRoleRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TokenCreateAgainstRoleRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "display_name": obj.get("display_name"),
            "entity_alias": obj.get("entity_alias"),
            "explicit_max_ttl": obj.get("explicit_max_ttl"),
            "id": obj.get("id"),
            "lease": obj.get("lease"),
            "meta": obj.get("meta"),
            "no_default_policy": obj.get("no_default_policy"),
            "no_parent": obj.get("no_parent"),
            "num_uses": obj.get("num_uses"),
            "period": obj.get("period"),
            "policies": obj.get("policies"),
            "renewable": obj.get("renewable") if obj.get("renewable") is not None else True,
            "ttl": obj.get("ttl"),
            "type": obj.get("type")
        })
        return _obj





# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class PkiWriteIssuerRequest(BaseModel):
    """
    PkiWriteIssuerRequest
    """ # noqa: E501
    crl_distribution_points: Optional[List[StrictStr]] = Field(default=None, description="Comma-separated list of URLs to be used for the CRL distribution points attribute. See also RFC 5280 Section 4.2.1.13.")
    enable_aia_url_templating: Optional[StrictBool] = Field(default=False, description="Whether or not to enabling templating of the above AIA fields. When templating is enabled the special values '{{issuer_id}}', '{{cluster_path}}', '{{cluster_aia_path}}' are available, but the addresses are not checked for URL validity until issuance time. Using '{{cluster_path}}' requires /config/cluster's 'path' member to be set on all PR Secondary clusters and using '{{cluster_aia_path}}' requires /config/cluster's 'aia_path' member to be set on all PR secondary clusters.")
    issuer_name: Optional[StrictStr] = Field(default=None, description="Provide a name to the generated or existing issuer, the name must be unique across all issuers and not be the reserved value 'default'")
    issuing_certificates: Optional[List[StrictStr]] = Field(default=None, description="Comma-separated list of URLs to be used for the issuing certificate attribute. See also RFC 5280 Section 4.2.2.1.")
    leaf_not_after_behavior: Optional[StrictStr] = Field(default='err', description="Behavior of leaf's NotAfter fields: \"err\" to error if the computed NotAfter date exceeds that of this issuer; \"truncate\" to silently truncate to that of this issuer; or \"permit\" to allow this issuance to succeed (with NotAfter exceeding that of an issuer). Note that not all values will results in certificates that can be validated through the entire validity period. It is suggested to use \"truncate\" for intermediate CAs and \"permit\" only for root CAs.")
    manual_chain: Optional[List[StrictStr]] = Field(default=None, description="Chain of issuer references to use to build this issuer's computed CAChain field, when non-empty.")
    ocsp_servers: Optional[List[StrictStr]] = Field(default=None, description="Comma-separated list of URLs to be used for the OCSP servers attribute. See also RFC 5280 Section 4.2.2.1.")
    revocation_signature_algorithm: Optional[StrictStr] = Field(default='', description="Which x509.SignatureAlgorithm name to use for signing CRLs. This parameter allows differentiation between PKCS#1v1.5 and PSS keys and choice of signature hash algorithm. The default (empty string) value is for Go to select the signature algorithm. This can fail if the underlying key does not support the requested signature algorithm, which may not be known at modification time (such as with PKCS#11 managed RSA keys).")
    usage: Optional[List[StrictStr]] = Field(default=None, description="Comma-separated list (or string slice) of usages for this issuer; valid values are \"read-only\", \"issuing-certificates\", \"crl-signing\", and \"ocsp-signing\". Multiple values may be specified. Read-only is implicit and always set.")
    __properties: ClassVar[List[str]] = ["crl_distribution_points", "enable_aia_url_templating", "issuer_name", "issuing_certificates", "leaf_not_after_behavior", "manual_chain", "ocsp_servers", "revocation_signature_algorithm", "usage"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PkiWriteIssuerRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PkiWriteIssuerRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "crl_distribution_points": obj.get("crl_distribution_points"),
            "enable_aia_url_templating": obj.get("enable_aia_url_templating") if obj.get("enable_aia_url_templating") is not None else False,
            "issuer_name": obj.get("issuer_name"),
            "issuing_certificates": obj.get("issuing_certificates"),
            "leaf_not_after_behavior": obj.get("leaf_not_after_behavior") if obj.get("leaf_not_after_behavior") is not None else 'err',
            "manual_chain": obj.get("manual_chain"),
            "ocsp_servers": obj.get("ocsp_servers"),
            "revocation_signature_algorithm": obj.get("revocation_signature_algorithm") if obj.get("revocation_signature_algorithm") is not None else '',
            "usage": obj.get("usage")
        })
        return _obj


